@@ -49,6 +49,7 @@ PATCH_MODULES = {
     "algoliasearch": True,
     "futures": True,
     "freezegun": False,  # deprecated, to be removed in ddtrace 4.x
+    "google_adk": True,
     "google_generativeai": True,
     "google_genai": True,
     "gevent": True,
@@ -118,6 +119,7 @@ PATCH_MODULES = {
     "selenium": True,
     "valkey": True,
     "openai_agents": True,
+    "ray": False,
     "protobuf": config._data_streams_enabled,
 }
 
@@ -163,8 +165,10 @@ _MODULES_FOR_CONTRIB = {
     "azure_servicebus": ("azure.servicebus",),
     "httplib": ("http.client",),
     "kafka": ("confluent_kafka",),
+    "google_adk": ("google.adk",),
     "google_generativeai": ("google.generativeai",),
     "google_genai": ("google.genai",),
+    "langchain": ("langchain_core",),
     "langgraph": (
         "langgraph",
         "langgraph.graph",
