@@ -119,15 +119,16 @@ class Span(object):
         "_meta",
         "_meta_struct",
         "error",
+        "context",
         "_metrics",
         "_store",
         "span_type",
         "start_ns",
         "duration_ns",
         # Internal attributes
-        "_context",
         "_parent_context",
         "_local_root_value",
+        "_service_entry_span_value",
         "_parent",
         "_ignored_exceptions",
         "_on_finish_callbacks",
@@ -210,7 +211,11 @@ class Span(object):
         self._on_finish_callbacks = [] if on_finish is None else on_finish
 
         self._parent_context: Optional[Context] = context
-        self._context = context.copy(self.trace_id, self.span_id) if context else None
+        self.context: Context = (
+            context.copy(self.trace_id, self.span_id)
+            if context
+            else Context(trace_id=self.trace_id, span_id=self.span_id, is_remote=False)
+        )
 
         self._links: List[Union[SpanLink, _SpanPointer]] = []
         if links:
@@ -221,18 +226,15 @@ class Span(object):
         self._parent: Optional["Span"] = None
         self._ignored_exceptions: Optional[List[Type[Exception]]] = None
         self._local_root_value: Optional["Span"] = None  # None means this is the root span.
+        self._service_entry_span_value: Optional["Span"] = None  # None means this is the service entry span.
         self._store: Optional[Dict[str, Any]] = None
 
     def _update_tags_from_context(self) -> None:
-        context = self._context
-        if context is None:
-            return
-
-        with context:
-            for tag in context._meta:
-                self._meta.setdefault(tag, context._meta[tag])
-            for metric in context._metrics:
-                self._metrics.setdefault(metric, context._metrics[metric])
+        with self.context:
+            for tag in self.context._meta:
+                self._meta.setdefault(tag, self.context._meta[tag])
+            for metric in self.context._metrics:
+                self._metrics.setdefault(metric, self.context._metrics[metric])
 
     def _ignore_exception(self, exc: Type[Exception]) -> None:
         if self._ignored_exceptions is None:
@@ -701,30 +703,30 @@ class Span(object):
 
         return False
 
-    @property
-    def context(self) -> Context:
-        """Return the trace context for this span."""
-        if self._context is None:
-            self._context = Context(trace_id=self.trace_id, span_id=self.span_id, is_remote=False)
-        return self._context
-
     @property
     def _local_root(self) -> "Span":
-        if self._local_root_value is None:
-            return self
-        return self._local_root_value
+        return self._local_root_value or self
 
     @_local_root.setter
     def _local_root(self, value: "Span") -> None:
-        if value is not self:
-            self._local_root_value = value
-        else:
-            self._local_root_value = None
+        self._local_root_value = value if value is not self else None
 
     @_local_root.deleter
     def _local_root(self) -> None:
         del self._local_root_value
 
+    @property
+    def _service_entry_span(self) -> "Span":
+        return self._service_entry_span_value or self
+
+    @_service_entry_span.setter
+    def _service_entry_span(self, span: "Span") -> None:
+        self._service_entry_span_value = None if span is self else span
+
+    @_service_entry_span.deleter
+    def _service_entry_span(self) -> None:
+        del self._service_entry_span_value
+
     def link_span(self, context: Context, attributes: Optional[Dict[str, Any]] = None) -> None:
         """Defines a causal relationship between two spans"""
         if not context.trace_id or not context.span_id:
@@ -859,7 +861,8 @@ class Span(object):
             f"metrics={self._metrics}, "
             f"links={self._links}, "
             f"events={self._events}, "
-            f"context={self._context})"
+            f"context={self.context}, "
+            f"service_entry_span_name={self._service_entry_span.name})"
         )
 
     def __str__(self) -> str:
