@@ -20,6 +20,7 @@ from ddtrace._trace.processor import SpanAggregator
 from ddtrace._trace.processor import SpanProcessor
 from ddtrace._trace.processor import TopLevelSpanProcessor
 from ddtrace._trace.processor import TraceProcessor
+from ddtrace._trace.processor.resource_renaming import ResourceRenamingProcessor
 from ddtrace._trace.provider import BaseContextProvider
 from ddtrace._trace.provider import DefaultContextProvider
 from ddtrace._trace.span import Span
@@ -74,6 +75,9 @@ def _default_span_processors_factory(
     span_processors: List[SpanProcessor] = []
     span_processors += [TopLevelSpanProcessor()]
 
+    if config._trace_resource_renaming_enabled:
+        span_processors.append(ResourceRenamingProcessor())
+
     # When using the NativeWriter stats are computed by the native code.
     if config._trace_compute_stats and not config._trace_writer_native:
         # Inline the import to avoid pulling in ddsketch or protobuf
@@ -462,17 +466,19 @@ class Tracer(object):
                 child_of = new_ctx
 
         parent: Optional[Span] = None
+        context: Optional[Context] = None
+        trace_id: Optional[int] = None
+        parent_id: Optional[int] = None
+
         if child_of is not None:
             if isinstance(child_of, Context):
                 context = child_of
             else:
                 context = child_of.context
                 parent = child_of
-        else:
-            context = Context(is_remote=False)
 
-        trace_id = context.trace_id
-        parent_id = context.span_id
+            trace_id = context.trace_id
+            parent_id = context.span_id
 
         # The following precedence is used for a new span's service:
         # 1. Explicitly provided service name
@@ -489,8 +495,8 @@ class Tracer(object):
         # Update the service name based on any mapping
         service = config.service_mapping.get(service, service)
 
-        links = context._span_links if not parent else []
-        if trace_id or links or context._baggage:
+        links = context._span_links if not parent and context else []
+        if trace_id or links or (context and context._baggage):
             # child_of a non-empty context, so either a local child span or from a remote context
             span = Span(
                 name=name,
