@@ -1,3 +1,4 @@
+from ddtrace.appsec._iast._iast_request_context_base import is_iast_request_enabled
 from ddtrace.appsec._iast._logs import iast_error
 from ddtrace.appsec._iast._taint_tracking._taint_objects import taint_pyobject
 from ddtrace.appsec._iast._taint_tracking._taint_objects_base import get_tainted_ranges
@@ -131,7 +132,7 @@ def _langchain_llm_generate_after(prompts, completions):
                 )
                 setattr(gen, text_attr, new_text)
     except Exception as e:
-        iast_error(f"propagation::source::langchain _langchain_llm_generate_after. {e}")
+        iast_error("propagation::source::langchain _langchain_llm_generate_after", e)
 
 
 def _langchain_chatmodel_generate_after(messages, completions):
@@ -199,7 +200,7 @@ def _langchain_chatmodel_generate_after(messages, completions):
                                 if isinstance(arguments, str):
                                     function_call["arguments"] = _iast_taint_if_str(source, arguments)
     except Exception as e:
-        iast_error(f"propagation::source::langchain _langchain_chatmodel_generate_after. {e}")
+        iast_error("propagation::source::langchain _langchain_chatmodel_generate_after", e)
 
 
 def _langchain_stream_chunk_callback(interface_type, args, kwargs):
@@ -217,7 +218,7 @@ def _create_taint_chunk_callback(source):
         try:
             _langchain_iast_taint_chunk(source, chunk)
         except Exception as e:
-            iast_error(f"propagation::source::langchain _langchain_iast_taint_chunk. {e}")
+            iast_error("propagation::source::langchain _langchain_iast_taint_chunk", e)
 
     return _iast_chunk_taint
 
@@ -323,7 +324,7 @@ async def _wrapper_prompt_template_aformat(func, instance, args, kwargs):
 
 def _propagate_prompt_template_format(kwargs, result):
     try:
-        if not asm_config.is_iast_request_enabled:
+        if not is_iast_request_enabled():
             return result
 
         for value in kwargs.values():
@@ -332,7 +333,7 @@ def _propagate_prompt_template_format(kwargs, result):
                 source = ranges[0].source
                 return taint_pyobject(result, source.name, source.value, source.origin)
     except Exception as e:
-        iast_error(f"propagation::source::langchain iast_propagate_prompt_template_format. {e}")
+        iast_error("propagation::source::langchain iast_propagate_prompt_template_format", e)
     return result
 
 
@@ -363,5 +364,5 @@ def _propagante_agentoutput_parse(args, kwargs, result):
                 values = result.return_values
                 values["output"] = taint_pyobject(values["output"], source.name, source.value, source.origin)
     except Exception as e:
-        iast_error(f"propagation::source::langchain taint_parser_output. {e}")
+        iast_error("propagation::source::langchain taint_parser_output", e)
     return result
