@@ -5,6 +5,4 @@
 #define MSG_ERROR_N_PARAMS "iast::propagation::native::error::Invalid number of params"
 #define MSG_ERROR_SET_RANGES                                                                                           \
     "iast::propagation::native::error::Set ranges error: Empty ranges or Tainted Map isn't initialized"
-#define MSG_ERROR_GET_RANGES_TYPE                                                                                      \
-    "iast::propagation::native::error::Get ranges error: Invalid type of candidate_text variable"
 #define MSG_ERROR_TAINT_MAP "iast::propagation::native::error::Tainted Map isn't initialized"
\ No newline at end of file
