@@ -167,14 +167,23 @@ def disable_asm(local_tracer: Tracer):
         AppSecSpanProcessor.disable()
 
         asm_config._asm_enabled = False
+        if asm_config._api_security_active:
+            from ddtrace.appsec._api_security.api_manager import APIManager
+
+            APIManager.disable()
+
         local_tracer.configure(appsec_enabled=False)
 
 
 def enable_asm(local_tracer: Tracer):
-    if not asm_config._asm_enabled:
+    if asm_config._asm_can_be_enabled and not asm_config._asm_enabled:
         from ddtrace.appsec._listeners import load_appsec
 
         asm_config._asm_enabled = True
+        if asm_config._api_security_enabled:
+            from ddtrace.appsec._api_security.api_manager import APIManager
+
+            APIManager.enable()
         load_appsec()
         local_tracer.configure(appsec_enabled=True, appsec_enabled_origin=APPSEC.ENABLED_ORIGIN_RC)
 
