@@ -3,20 +3,10 @@ import json
 from typing import Any
 from typing import Dict
 from typing import List
-from typing import Text
-from typing import Union
-
-from ddtrace.internal.utils.http import Response
-from ddtrace.internal.utils.http import get_connection
-
-
-try:
-    from typing import TypedDict
-except ImportError:
-    from typing_extensions import TypedDict
 from typing import Optional  # noqa:F401
-
-from typing_extensions import NotRequired
+from typing import Text
+from typing import TypedDict
+from typing import Union
 
 from ddtrace import config
 from ddtrace import tracer as ddtracer
@@ -26,6 +16,8 @@ from ddtrace.internal import telemetry
 import ddtrace.internal.logger as ddlogger
 from ddtrace.internal.telemetry import TELEMETRY_NAMESPACE
 from ddtrace.internal.telemetry.metrics_namespaces import MetricTagType
+from ddtrace.internal.utils.http import Response
+from ddtrace.internal.utils.http import get_connection
 from ddtrace.settings.asm import ai_guard_config
 
 
@@ -37,16 +29,22 @@ ABORT = "ABORT"
 ACTIONS = [ALLOW, DENY, ABORT]
 
 
-class Prompt(TypedDict):
+class _PromptOptional(TypedDict, total=False):
+    output: str
+
+
+class Prompt(_PromptOptional):
     role: str
     content: str
-    output: NotRequired[str]
 
 
-class ToolCall(TypedDict):
+class _ToolCallOptional(TypedDict, total=False):
+    output: str
+
+
+class ToolCall(_ToolCallOptional):
     tool_name: str
     tool_args: Dict[Union[Text, bytes], Any]
-    output: NotRequired[str]
 
 
 Evaluation = Union[Prompt, ToolCall]
