@@ -54,7 +54,7 @@ _quantize_text = Union[Text, bytes]
 _quantize_param = Union[_quantize_text, List[_quantize_text], Dict[_quantize_text, Any], Any]
 
 
-def resource_from_cache_prefix(resource, cache):
+def resource_from_cache_prefix(resource: str, cache: Any) -> str:
     """
     Combine the resource name with the cache prefix (if any)
     """
