@@ -87,7 +87,7 @@ def _call_asm_wrap(func, instance, *args, **kwargs):
 
 def _wrap_request(func, instance, args, kwargs):
     # Use any attached tracer if available, otherwise use the global tracer
-    if asm_config._iast_enabled or (asm_config._asm_enabled and asm_config._ep_enabled):
+    if asm_config._asm_enabled and asm_config._ep_enabled:
         func_to_call = functools.partial(_call_asm_wrap, func, instance)
     else:
         func_to_call = func
