@@ -8,6 +8,7 @@ import mcp
 
 from ddtrace import config
 from ddtrace._trace.pin import Pin
+from ddtrace._trace.span import Span
 from ddtrace.contrib.internal.trace_utils import activate_distributed_headers
 from ddtrace.contrib.trace_utils import unwrap
 from ddtrace.contrib.trace_utils import with_traced_module
@@ -41,7 +42,7 @@ def _supported_versions() -> Dict[str, str]:
     return {"mcp": ">=1.10.0"}
 
 
-def _set_distributed_headers_into_mcp_request(pin, request):
+def _set_distributed_headers_into_mcp_request(pin: Pin, request):
     """Inject distributed tracing headers into MCP request metadata."""
     span = pin.tracer.current_span()
     if span is None:
@@ -97,7 +98,7 @@ def _extract_distributed_headers_from_mcp_request(kwargs: Dict[str, Any]) -> Opt
 
 
 @with_traced_module
-def traced_send_request(mcp, pin, func, instance, args, kwargs):
+def traced_send_request(mcp, pin: Pin, func, instance, args: tuple, kwargs: dict):
     """Injects distributed tracing headers into MCP request metadata"""
     if not args or not config.mcp.distributed_tracing:
         return func(*args, **kwargs)
@@ -107,7 +108,7 @@ def traced_send_request(mcp, pin, func, instance, args, kwargs):
 
 
 @with_traced_module
-async def traced_call_tool(mcp, pin, func, instance, args, kwargs):
+async def traced_call_tool(mcp, pin: Pin, func, instance, args: tuple, kwargs: dict):
     integration = mcp._datadog_integration
 
     span = integration.trace(pin, CLIENT_TOOL_CALL_OPERATION_NAME, submit_to_llmobs=True)
@@ -129,7 +130,7 @@ async def traced_call_tool(mcp, pin, func, instance, args, kwargs):
 
 
 @with_traced_module
-async def traced_tool_manager_call_tool(mcp, pin, func, instance, args, kwargs):
+async def traced_tool_manager_call_tool(mcp, pin: Pin, func, instance, args: tuple, kwargs: dict):
     integration = mcp._datadog_integration
     if config.mcp.distributed_tracing:
         activate_distributed_headers(pin.tracer, config.mcp, _extract_distributed_headers_from_mcp_request(kwargs))
@@ -152,6 +153,74 @@ async def traced_tool_manager_call_tool(mcp, pin, func, instance, args, kwargs):
         span.finish()
 
 
+@with_traced_module
+async def traced_client_session_initialize(mcp, pin: Pin, func, instance, args: tuple, kwargs: dict):
+    integration: MCPIntegration = mcp._datadog_integration
+
+    with integration.trace(pin, "%s.%s" % (instance.__class__.__name__, func.__name__), submit_to_llmobs=True) as span:
+        response = None
+        try:
+            response = await func(*args, **kwargs)
+            return response
+        finally:
+            integration.llmobs_set_tags(span, args=args, kwargs=kwargs, response=response, operation="initialize")
+
+
+@with_traced_module
+async def traced_client_session_list_tools(mcp, pin: Pin, func, instance, args: tuple, kwargs: dict):
+    integration: MCPIntegration = mcp._datadog_integration
+
+    with integration.trace(pin, "%s.%s" % (instance.__class__.__name__, func.__name__), submit_to_llmobs=True) as span:
+        response = None
+        try:
+            response = await func(*args, **kwargs)
+            return response
+        finally:
+            integration.llmobs_set_tags(span, args=args, kwargs=kwargs, response=response, operation="list_tools")
+
+
+@with_traced_module
+async def traced_client_session_aenter(mcp, pin: Pin, func, instance, args: tuple, kwargs: dict):
+    integration: MCPIntegration = mcp._datadog_integration
+    span = integration.trace(pin, instance.__class__.__name__, submit_to_llmobs=True)
+
+    setattr(instance, "_dd_span", span)
+    try:
+        return await func(*args, **kwargs)
+    except Exception:
+        span.set_exc_info(*sys.exc_info())
+        span.finish()
+        raise
+
+
+@with_traced_module
+async def traced_client_session_aexit(mcp, pin: Pin, func, instance, args: tuple, kwargs: dict):
+    integration: MCPIntegration = mcp._datadog_integration
+    span: Optional[Span] = getattr(instance, "_dd_span", None)
+
+    try:
+        return await func(*args, **kwargs)
+    except Exception:
+        if span:
+            span.set_exc_info(*sys.exc_info())
+        raise
+    finally:
+        if not span:
+            return
+
+        integration.llmobs_set_tags(
+            span,
+            args=[],
+            kwargs=dict(
+                read_stream=_get_attr(instance, "_read_stream", None),
+                write_stream=_get_attr(instance, "_write_stream", None),
+            ),
+            response=None,
+            operation="session",
+        )
+        span.finish()
+
+
 def patch():
     if getattr(mcp, "__datadog_patch", False):
         return
@@ -164,8 +233,12 @@ def patch():
     from mcp.server.fastmcp.tools.tool_manager import ToolManager
     from mcp.shared.session import BaseSession
 
+    wrap(ClientSession, "__aenter__", traced_client_session_aenter(mcp))
+    wrap(ClientSession, "__aexit__", traced_client_session_aexit(mcp))
     wrap(BaseSession, "send_request", traced_send_request(mcp))
     wrap(ClientSession, "call_tool", traced_call_tool(mcp))
+    wrap(ClientSession, "list_tools", traced_client_session_list_tools(mcp))
+    wrap(ClientSession, "initialize", traced_client_session_initialize(mcp))
     wrap(ToolManager, "call_tool", traced_tool_manager_call_tool(mcp))
 
 
@@ -179,8 +252,12 @@ def unpatch():
     from mcp.server.fastmcp.tools.tool_manager import ToolManager
     from mcp.shared.session import BaseSession
 
+    unwrap(ClientSession, "__aenter__")
+    unwrap(ClientSession, "__aexit__")
     unwrap(BaseSession, "send_request")
     unwrap(ClientSession, "call_tool")
+    unwrap(ClientSession, "list_tools")
+    unwrap(ClientSession, "initialize")
     unwrap(ToolManager, "call_tool")
 
     delattr(mcp, "_datadog_integration")
