@@ -1,12 +1,13 @@
 from openai.version import VERSION as OPENAI_VERSION
 
-from ddtrace.contrib.internal.openai.utils import TracedOpenAIAsyncStream
-from ddtrace.contrib.internal.openai.utils import TracedOpenAIStream
+from ddtrace.contrib.internal.openai.utils import OpenAIAsyncStreamHandler
+from ddtrace.contrib.internal.openai.utils import OpenAIStreamHandler
 from ddtrace.contrib.internal.openai.utils import _is_async_generator
 from ddtrace.contrib.internal.openai.utils import _is_generator
 from ddtrace.contrib.internal.openai.utils import _loop_handler
 from ddtrace.contrib.internal.openai.utils import _process_finished_stream
 from ddtrace.internal.utils.version import parse_version
+from ddtrace.llmobs._integrations.base_stream_handler import make_traced_stream
 
 
 API_VERSION = "v1"
@@ -83,8 +84,6 @@ class _EndpointHook:
 
 
 class _BaseCompletionHook(_EndpointHook):
-    _request_arg_params = ()
-
     def _handle_streamed_response(self, integration, span, kwargs, resp, operation_type=""):
         """Handle streamed response objects returned from completions/chat/response endpoint calls.
 
@@ -93,9 +92,14 @@ class _BaseCompletionHook(_EndpointHook):
         """
         if parse_version(OPENAI_VERSION) >= (1, 6, 0):
             if _is_async_generator(resp):
-                return TracedOpenAIAsyncStream(resp, integration, span, kwargs, operation_type)
+                return make_traced_stream(
+                    resp,
+                    OpenAIAsyncStreamHandler(integration, span, None, kwargs, operation_type=operation_type),
+                )
             elif _is_generator(resp):
-                return TracedOpenAIStream(resp, integration, span, kwargs, operation_type)
+                return make_traced_stream(
+                    resp, OpenAIStreamHandler(integration, span, None, kwargs, operation_type=operation_type)
+                )
 
         def shared_gen():
             try:
@@ -179,7 +183,6 @@ class _CompletionWithRawResponseHook(_CompletionHook):
 
 
 class _ChatCompletionHook(_BaseCompletionHook):
-    _request_arg_params = ()
     _request_kwarg_params = (
         "model",
         "engine",
@@ -218,7 +221,6 @@ class _ChatCompletionWithRawResponseHook(_ChatCompletionHook):
 
 
 class _EmbeddingHook(_EndpointHook):
-    _request_arg_params = ()
     _request_kwarg_params = ("model", "engine")
     _response_attrs = ("model",)
     ENDPOINT_NAME = "embeddings"
@@ -228,8 +230,6 @@ class _EmbeddingHook(_EndpointHook):
     def _record_response(self, pin, integration, span, args, kwargs, resp, error):
         resp = super()._record_response(pin, integration, span, args, kwargs, resp, error)
         integration.llmobs_set_tags(span, args=[], kwargs=kwargs, response=resp, operation="embedding")
-        if not resp:
-            return
         return resp
 
 
@@ -322,17 +322,6 @@ class _RetrieveHook(_EndpointHook):
 
     def _record_response(self, pin, integration, span, args, kwargs, resp, error):
         resp = super()._record_response(pin, integration, span, args, kwargs, resp, error)
-        if not resp:
-            return
-        if hasattr(resp, "hyperparams"):
-            for hyperparam in ("batch_size", "learning_rate_multiplier", "n_epochs", "prompt_loss_weight"):
-                val = getattr(resp.hyperparams, hyperparam, "")
-                span.set_tag_str("openai.response.hyperparams.%s" % hyperparam, str(val))
-        for resp_attr in ("result_files", "training_files", "validation_files"):
-            if hasattr(resp, resp_attr):
-                span.set_metric("openai.response.%s_count" % resp_attr, len(getattr(resp, resp_attr, [])))
-        if hasattr(resp, "events"):
-            span.set_metric("openai.response.events_count", len(resp.events))
         return resp
 
 
@@ -420,162 +409,46 @@ class _ImageHook(_EndpointHook):
         super()._record_request(pin, integration, instance, span, args, kwargs)
         span.set_tag_str("openai.request.model", "dall-e")
 
-    def _record_response(self, pin, integration, span, args, kwargs, resp, error):
-        resp = super()._record_response(pin, integration, span, args, kwargs, resp, error)
-        if not resp:
-            return
-        choices = resp.data
-        span.set_metric("openai.response.images_count", len(choices))
-        if integration.is_pc_sampled_span(span):
-            for idx, choice in enumerate(choices):
-                if getattr(choice, "b64_json", None) is not None:
-                    span.set_tag_str("openai.response.images.%d.b64_json" % idx, "returned")
-                else:
-                    span.set_tag_str("openai.response.images.%d.url" % idx, integration.trunc(choice.url))
-        return resp
-
 
 class _ImageCreateHook(_ImageHook):
-    _request_arg_params = ("api_key", "api_base", "api_type", "api_version", "organization")
-    _request_kwarg_params = ("prompt", "n", "size", "response_format", "user")
     ENDPOINT_NAME = "images/generations"
     OPERATION_ID = "createImage"
 
 
 class _ImageEditHook(_ImageHook):
-    _request_arg_params = (None, None, "api_key", "api_base", "api_type", "api_version", "organization")
-    _request_kwarg_params = ("prompt", "n", "size", "response_format", "user", "image", "mask")
     ENDPOINT_NAME = "images/edits"
     OPERATION_ID = "createImageEdit"
 
-    def _record_request(self, pin, integration, instance, span, args, kwargs):
-        super()._record_request(pin, integration, instance, span, args, kwargs)
-        if not integration.is_pc_sampled_span:
-            return
-        image = args[0] if len(args) >= 1 else kwargs.get("image", "")
-        mask = args[1] if len(args) >= 2 else kwargs.get("mask", "")
-        if image:
-            if hasattr(image, "name"):
-                span.set_tag_str("openai.request.image", integration.trunc(image.name.split("/")[-1]))
-            else:
-                span.set_tag_str("openai.request.image", "")
-        if mask:
-            if hasattr(mask, "name"):
-                span.set_tag_str("openai.request.mask", integration.trunc(mask.name.split("/")[-1]))
-            else:
-                span.set_tag_str("openai.request.mask", "")
-
 
 class _ImageVariationHook(_ImageHook):
-    _request_arg_params = (None, "api_key", "api_base", "api_type", "api_version", "organization")
-    _request_kwarg_params = ("n", "size", "response_format", "user", "image")
     ENDPOINT_NAME = "images/variations"
     OPERATION_ID = "createImageVariation"
 
-    def _record_request(self, pin, integration, instance, span, args, kwargs):
-        super()._record_request(pin, integration, instance, span, args, kwargs)
-        if not integration.is_pc_sampled_span:
-            return
-        image = args[0] if len(args) >= 1 else kwargs.get("image", "")
-        if image:
-            if hasattr(image, "name"):
-                span.set_tag_str("openai.request.image", integration.trunc(image.name.split("/")[-1]))
-            else:
-                span.set_tag_str("openai.request.image", "")
-
 
 class _BaseAudioHook(_EndpointHook):
-    _request_arg_params = ("model", None, "api_key", "api_base", "api_type", "api_version", "organization")
-    _response_attrs = ("language", "duration")
+    _request_arg_params = ("model",)
     ENDPOINT_NAME = "audio"
     HTTP_METHOD_TYPE = "POST"
 
-    def _record_request(self, pin, integration, instance, span, args, kwargs):
-        super()._record_request(pin, integration, instance, span, args, kwargs)
-        if not integration.is_pc_sampled_span:
-            return
-        audio_file = args[1] if len(args) >= 2 else kwargs.get("file", "")
-        if audio_file and hasattr(audio_file, "name"):
-            span.set_tag_str("openai.request.filename", integration.trunc(audio_file.name.split("/")[-1]))
-        else:
-            span.set_tag_str("openai.request.filename", "")
-
-    def _record_response(self, pin, integration, span, args, kwargs, resp, error):
-        resp = super()._record_response(pin, integration, span, args, kwargs, resp, error)
-        text = ""
-        if resp:
-            resp_to_tag = resp.model_dump() if hasattr(resp, "model_dump") else resp
-            if isinstance(resp_to_tag, str):
-                text = resp
-            elif isinstance(resp_to_tag, dict):
-                text = resp_to_tag.get("text", "")
-                if "segments" in resp_to_tag:
-                    span.set_metric("openai.response.segments_count", len(resp_to_tag.get("segments")))
-            if integration.is_pc_sampled_span(span):
-                span.set_tag_str("openai.response.text", integration.trunc(text))
-        return resp
-
 
 class _AudioTranscriptionHook(_BaseAudioHook):
-    _request_kwarg_params = (
-        "prompt",
-        "response_format",
-        "temperature",
-        "language",
-        "user",
-    )
     ENDPOINT_NAME = "audio/transcriptions"
     OPERATION_ID = "createTranscription"
 
 
 class _AudioTranslationHook(_BaseAudioHook):
-    _request_kwarg_params = (
-        "prompt",
-        "response_format",
-        "temperature",
-        "user",
-    )
     ENDPOINT_NAME = "audio/translations"
     OPERATION_ID = "createTranslation"
 
 
 class _ModerationHook(_EndpointHook):
-    _request_arg_params = ("input", "model", "api_key")
-    _request_kwarg_params = ("input", "model")
+    _request_arg_params = ("model",)
+    _request_kwarg_params = ("model",)
     _response_attrs = ("id", "model")
-    _response_categories = (
-        "hate",
-        "hate/threatening",
-        "harassment",
-        "harassment/threatening",
-        "self-harm",
-        "self-harm/intent",
-        "self-harm/instructions",
-        "sexual",
-        "sexual/minors",
-        "violence",
-        "violence/graphic",
-    )
     ENDPOINT_NAME = "moderations"
     HTTP_METHOD_TYPE = "POST"
     OPERATION_ID = "createModeration"
 
-    def _record_request(self, pin, integration, instance, span, args, kwargs):
-        super()._record_request(pin, integration, instance, span, args, kwargs)
-
-    def _record_response(self, pin, integration, span, args, kwargs, resp, error):
-        resp = super()._record_response(pin, integration, span, args, kwargs, resp, error)
-        if not resp:
-            return
-        results = resp.results[0]
-        categories = results.categories
-        scores = results.category_scores
-        for category in self._response_categories:
-            span.set_metric("openai.response.category_scores.%s" % category, getattr(scores, category, 0))
-            span.set_metric("openai.response.categories.%s" % category, int(getattr(categories, category)))
-        span.set_metric("openai.response.flagged", int(results.flagged))
-        return resp
-
 
 class _BaseFileHook(_EndpointHook):
     ENDPOINT_NAME = "files"
@@ -633,7 +506,6 @@ class _FileDownloadHook(_BaseFileHook):
 
 
 class _ResponseHook(_BaseCompletionHook):
-    _request_arg_params = ()
     # Collecting all kwargs for responses
     _request_kwarg_params = ("model",)
     _response_attrs = ("model",)
