@@ -6,8 +6,8 @@ import pylibmc
 from wrapt import ObjectProxy
 
 # project
-import ddtrace
 from ddtrace import config
+from ddtrace._trace.pin import Pin
 from ddtrace.constants import _SPAN_MEASURED_KEY
 from ddtrace.constants import SPAN_KIND
 from ddtrace.contrib.internal.pylibmc.addrs import parse_addresses
@@ -50,7 +50,7 @@ class TracedClient(ObjectProxy):
         super(TracedClient, self).__init__(client)
 
         schematized_service = schematize_service_name(service)
-        pin = ddtrace.trace.Pin(service=schematized_service)
+        pin = Pin(service=schematized_service)
         pin._tracer = tracer
         pin.onto(self)
 
@@ -64,7 +64,7 @@ class TracedClient(ObjectProxy):
         # rewrap new connections.
         cloned = self.__wrapped__.clone(*args, **kwargs)
         traced_client = TracedClient(cloned)
-        pin = ddtrace.trace.Pin.get_from(self)
+        pin = Pin.get_from(self)
         if pin:
             pin.clone().onto(traced_client)
         return traced_client
@@ -155,7 +155,7 @@ class TracedClient(ObjectProxy):
 
     def _span(self, cmd_name):
         """Return a span timing the given command."""
-        pin = ddtrace.trace.Pin.get_from(self)
+        pin = Pin.get_from(self)
         if not pin or not pin.enabled():
             return self._no_span()
 
