@@ -1,6 +1,5 @@
 import os
 from pathlib import Path
-import re
 import typing as t
 
 from _pytest.runner import runtestprotocol
@@ -101,11 +100,12 @@ if _pytest_version_supports_attempt_to_fix():
 log = get_logger(__name__)
 
 
-_NODEID_REGEX = re.compile("^((?P<module>.*)/(?P<suite>[^/]*?))::(?P<name>.*?)$")
 OUTCOME_QUARANTINED = "quarantined"
 DISABLED_BY_TEST_MANAGEMENT_REASON = "Flaky test is disabled by Datadog"
 INCOMPATIBLE_PLUGINS = ("flaky", "rerunfailures")
 
+skipped_suites = set()
+
 skip_pytest_runtest_protocol = False
 
 # Module-level variable to store the current test's coverage collector
@@ -151,13 +151,27 @@ def _handle_itr_should_skip(item, test_id) -> bool:
         if hasattr(item.config, "workeroutput"):
             if "itr_skipped_count" not in item.config.workeroutput:
                 item.config.workeroutput["itr_skipped_count"] = 0
-            item.config.workeroutput["itr_skipped_count"] += 1
+            if not is_suite_skipping_mode:
+                item.config.workeroutput["itr_skipped_count"] += 1
 
         return True
 
     return False
 
 
+def _handle_itr_xdist_skipped_suite(item, suite_id) -> bool:
+    if suite_id in skipped_suites:
+        log.debug("Suite is already skipped")
+        return False
+
+    if hasattr(item.config, "workeroutput"):
+        if "itr_skipped_count" not in item.config.workeroutput:
+            item.config.workeroutput["itr_skipped_count"] = 0
+        item.config.workeroutput["itr_skipped_count"] += 1
+    skipped_suites.add(suite_id)
+    return True
+
+
 def _handle_test_management(item, test_id):
     """Add a user property to identify quarantined tests, and mark them for skipping if quarantine is enabled in
     skipping mode.
@@ -605,6 +619,7 @@ def _pytest_runtest_protocol_post_yield(item, nextitem, coverage_collector):
     if next_test_id is None or next_test_id.parent_id != suite_id:
         if InternalTestSuite.is_itr_skippable(suite_id) and not InternalTestSuite.was_itr_forced_run(suite_id):
             InternalTestSuite.mark_itr_skipped(suite_id)
+            _handle_itr_xdist_skipped_suite(item, suite_id)
         else:
             _handle_coverage_dependencies(suite_id)
         InternalTestSuite.finish(suite_id)
