@@ -1,5 +1,4 @@
 from ddtrace import DDTraceDeprecationWarning
-from ddtrace.contrib.internal.pytest._utils import _USE_PLUGIN_V2
 from ddtrace.contrib.internal.pytest.plugin import is_enabled as is_ddtrace_enabled
 from ddtrace.vendor.debtcollector import deprecate
 
@@ -13,7 +12,3 @@ def pytest_configure(config):
                 removal_version="3.0.0",
                 category=DDTraceDeprecationWarning,
             )
-            if not _USE_PLUGIN_V2:
-                from ._plugin import _PytestBenchmarkPlugin
-
-                config.pluginmanager.register(_PytestBenchmarkPlugin(), "_datadog-pytest-benchmark")
