@@ -54,12 +54,6 @@ def patch():
         _w("requests", "Session.request", _wrap_request)
     Pin(_config=config.requests).onto(requests.Session)
 
-    if asm_config._iast_enabled:
-        from ddtrace.appsec._iast._metrics import _set_metric_iast_instrumented_sink
-        from ddtrace.appsec._iast.constants import VULN_SSRF
-
-        _set_metric_iast_instrumented_sink(VULN_SSRF)
-
 
 def unpatch():
     """Disable traced sessions"""
