@@ -57,7 +57,9 @@ def patch():
     _w("urllib3", "connectionpool.HTTPConnectionPool.urlopen", _wrap_urlopen)
     if asm_config._load_modules:
         from ddtrace.appsec._common_module_patches import wrapped_request_D8CB81E472AF98A2 as _wrap_request
+        from ddtrace.appsec._common_module_patches import wrapped_urllib3_make_request as _make_request
 
+        _w("urllib3.connectionpool", "HTTPConnectionPool._make_request", _make_request)
         if hasattr(urllib3, "_request_methods"):
             _w("urllib3._request_methods", "RequestMethods.request", _wrap_request)
         else:
@@ -65,12 +67,6 @@ def patch():
             _w("urllib3.request", "RequestMethods.request", _wrap_request)
     Pin().onto(urllib3.connectionpool.HTTPConnectionPool)
 
-    if asm_config._iast_enabled:
-        from ddtrace.appsec._iast._metrics import _set_metric_iast_instrumented_sink
-        from ddtrace.appsec._iast.constants import VULN_SSRF
-
-        _set_metric_iast_instrumented_sink(VULN_SSRF)
-
 
 def unpatch():
     """Disable trace for all urllib3 requests"""
