@@ -1,7 +1,5 @@
 from collections import deque
 from dataclasses import dataclass
-from itertools import count
-from pathlib import Path
 from threading import current_thread
 from types import FrameType
 from types import TracebackType
@@ -13,14 +11,16 @@ from ddtrace.debugging._probe.model import LogLineProbe
 from ddtrace.debugging._session import Session
 from ddtrace.debugging._signal.snapshot import DEFAULT_CAPTURE_LIMITS
 from ddtrace.debugging._signal.snapshot import Snapshot
-from ddtrace.debugging._uploader import LogsIntakeUploaderV1
+from ddtrace.debugging._uploader import SignalUploader
 from ddtrace.debugging._uploader import UploaderProduct
 from ddtrace.internal import core
+from ddtrace.internal.compat import Path
 from ddtrace.internal.logger import get_logger
 from ddtrace.internal.packages import is_user_code
 from ddtrace.internal.rate_limiter import BudgetRateLimiterWithJitter as RateLimiter
 from ddtrace.internal.rate_limiter import RateLimitExceeded
 from ddtrace.internal.utils.time import HourGlass
+from ddtrace.settings._config import config as global_config
 from ddtrace.settings.exception_replay import config
 from ddtrace.trace import Span
 
@@ -117,7 +117,7 @@ def unwind_exception_chain(
     chain: ExceptionChain = deque()
 
     while exc is not None:
-        chain.append((exc, tb))
+        chain.appendleft((exc, tb))
 
         if exc.__cause__ is not None:
             exc = exc.__cause__
@@ -132,7 +132,7 @@ def unwind_exception_chain(
     if chain:
         # If the chain is not trivial we generate an ID for the whole chain and
         # store it on the outermost exception, if not already generated.
-        exc, _ = chain[-1]
+        exc, _ = chain[0]
         try:
             exc_id = exc._dd_exc_id  # type: ignore[attr-defined]
         except AttributeError:
@@ -141,6 +141,27 @@ def unwind_exception_chain(
     return chain, exc_id
 
 
+def get_tb_frames_from_exception_chain(chain: ExceptionChain) -> t.List[TracebackType]:
+    """Get the frames from the exception chain."""
+    frames: t.List[TracebackType] = []
+
+    for _, tb in chain:
+        local_frames = []
+        if tb is None or tb.tb_frame is None:
+            continue
+
+        _tb: t.Optional[TracebackType] = tb
+        while _tb is not None:
+            local_frames.append(_tb)
+            _tb = _tb.tb_next
+
+        # Get only the last N frames from the traceback, where N is the
+        # configured max size for span tracebacks.
+        frames.extend(local_frames[-global_config._span_traceback_max_size :])
+
+    return frames
+
+
 class SpanExceptionProbe(LogLineProbe):
     @classmethod
     def build(cls, exc_id: uuid.UUID, frame: FrameType) -> "SpanExceptionProbe":
@@ -168,6 +189,8 @@ class SpanExceptionProbe(LogLineProbe):
 
 @dataclass
 class SpanExceptionSnapshot(Snapshot):
+    __type__ = "snapshot"
+
     exc_id: t.Optional[uuid.UUID] = None
 
     @property
@@ -212,58 +235,69 @@ def get_snapshot_count(span: Span) -> int:
     if root is None:
         return 0
 
-    count = root.get_metric(SNAPSHOT_COUNT_TAG)
-    if count is None:
+    if (count := root.get_metric(SNAPSHOT_COUNT_TAG)) is None:
         return 0
 
     return int(count)
 
 
 class SpanExceptionHandler:
-    __uploader__ = LogsIntakeUploaderV1
+    __uploader__ = SignalUploader
 
     _instance: t.Optional["SpanExceptionHandler"] = None
 
-    def _capture_tb_frame_for_span(
-        self, span: Span, tb: TracebackType, exc_id: uuid.UUID, seq_nr: int = 1, only_user_code: bool = True
+    def _attach_tb_frame_snapshot_to_span(
+        self,
+        span: Span,
+        tb: TracebackType,
+        exc_id: uuid.UUID,
+        seq_nr: int = 1,
+        only_user_code: bool = True,
+        cached_only: bool = False,
     ) -> bool:
-        frame = tb.tb_frame
-        code = frame.f_code
-        if only_user_code and not is_user_code(Path(code.co_filename)):
-            return False
-
-        snapshot = None
-        snapshot_id = frame.f_locals.get(SNAPSHOT_KEY, None)
-        if snapshot_id is None:
-            # We don't have a snapshot for the frame so we create one
-            snapshot = SpanExceptionSnapshot(
-                probe=SpanExceptionProbe.build(exc_id, frame),
-                frame=frame,
-                thread=current_thread(),
-                trace_context=span,
-                exc_id=exc_id,
-            )
-
-            # Capture
-            try:
-                snapshot.do_line()
-            except Exception:
-                log.exception("Error capturing exception replay snapshot %r", snapshot)
+        try:
+            frame = tb.tb_frame
+            code = frame.f_code
+            if only_user_code and not is_user_code(Path(code.co_filename)):
                 return False
 
-            # Collect
-            self.__uploader__.get_collector().push(snapshot)
+            snapshot = None
+            snapshot_id = frame.f_locals.get(SNAPSHOT_KEY, None)
+            if snapshot_id is None:
+                # We don't have a snapshot for the frame so we create one
+                if cached_only:
+                    # If we only want a cached snapshot we return True as a signal
+                    # that we would have captured, but we actually skip generating
+                    # a new snapshot.
+                    return True
 
-            # Memoize
-            frame.f_locals[SNAPSHOT_KEY] = snapshot_id = snapshot.uuid
+                snapshot = SpanExceptionSnapshot(
+                    probe=SpanExceptionProbe.build(exc_id, frame),
+                    frame=frame,
+                    thread=current_thread(),
+                    trace_context=span,
+                    exc_id=exc_id,
+                )
 
-        # Add correlation tags on the span
-        span.set_tag_str(FRAME_SNAPSHOT_ID_TAG % seq_nr, snapshot_id)
-        span.set_tag_str(FRAME_FUNCTION_TAG % seq_nr, code.co_name)
-        span.set_tag_str(FRAME_FILE_TAG % seq_nr, code.co_filename)
-        span.set_tag_str(FRAME_LINE_TAG % seq_nr, str(tb.tb_lineno))
+                # Capture
+                snapshot.do_line()
 
-        return snapshot is not None
+                # Collect
+                self.__uploader__.get_collector().push(snapshot)
+
+                # Memoize
+                frame.f_locals[SNAPSHOT_KEY] = snapshot_id = snapshot.uuid
+
+            # Add correlation tags on the span
+            span.set_tag_str(FRAME_SNAPSHOT_ID_TAG % seq_nr, snapshot_id)
+            span.set_tag_str(FRAME_FUNCTION_TAG % seq_nr, code.co_name)
+            span.set_tag_str(FRAME_FILE_TAG % seq_nr, code.co_filename)
+            span.set_tag_str(FRAME_LINE_TAG % seq_nr, str(tb.tb_lineno))
+
+            return snapshot is not None
+        except Exception:  # noqa: F841
+            log.exception("Error capturing exception replay snapshot")
+            return False
 
     def on_span_exception(
         self, span: Span, _exc_type: t.Type[BaseException], exc: BaseException, traceback: t.Optional[TracebackType]
@@ -286,28 +320,31 @@ class SpanExceptionHandler:
             # We have seen this exception recently
             return
 
-        seq = count(1)  # 1-based sequence number
-
         frames_captured = get_snapshot_count(span)
 
-        while chain and frames_captured < config.max_frames:
-            exc, _tb = chain.pop()  # LIFO: reverse the chain
+        # Capture more frames if we have budget left, otherwise set just the
+        # tags on the span for those frames that we have already captured.
+        for seq_nr, _tb in reversed(list(enumerate(get_tb_frames_from_exception_chain(chain), 1))):
+            has_snapshot_budget = frames_captured < config.max_frames
+            has_captured = self._attach_tb_frame_snapshot_to_span(
+                span, _tb, exc_id, seq_nr, cached_only=not has_snapshot_budget
+            )
+            if not has_snapshot_budget and has_captured:
+                # We would need to capture new frames at this point but we don't
+                # have budget left so we stop capturing.
+                break
 
-            if _tb is None or _tb.tb_frame is None:
-                # If we don't have a traceback there isn't much we can do
-                continue
+            frames_captured += has_captured
 
-            # DEV: We go from the handler up to the root exception
-            while _tb and frames_captured < config.max_frames:
-                frames_captured += self._capture_tb_frame_for_span(span, _tb, exc_id, next(seq))
-
-                # Move up the traceback
-                _tb = _tb.tb_next
+            if has_captured and frames_captured >= config.max_frames:
+                # The last capture has saturated the budget so we can stop
+                # capturing
+                break
 
         if not frames_captured and tb is not None:
             # Ensure we capture at least one frame if we have a traceback,
             # the one potentially closer to user code.
-            frames_captured += self._capture_tb_frame_for_span(span, tb, exc_id, only_user_code=False)
+            frames_captured += self._attach_tb_frame_snapshot_to_span(span, tb, exc_id, only_user_code=False)
 
         if frames_captured:
             span.set_tag_str(DEBUG_INFO_TAG, "true")
