@@ -1,3 +1,4 @@
+from ddtrace.settings.asm import ai_guard_config
 from ddtrace.settings.asm import config
 
 
@@ -18,6 +19,11 @@ def start():
 
         load_appsec()
 
+    if ai_guard_config._ai_guard_enabled:
+        from ddtrace.appsec._ai_guard import init_ai_guard
+
+        init_ai_guard()
+
 
 def restart(join=False):
     if config._asm_rc_enabled:
