@@ -378,7 +378,7 @@ class CIVisibility(Service):
 
             # The most recent API response overrides the first one
             try:
-                settings = self._api_client.fetch_settings()
+                settings = self._api_client.fetch_settings(read_from_cache=False)
             except Exception:
                 log.warning(
                     "Error checking Intelligent Test Runner API after git metadata upload,"
@@ -588,6 +588,10 @@ class CIVisibility(Service):
             log.debug("%s already enabled", cls.__name__)
             return
 
+        if not telemetry.get_config("DD_CIVISIBILITY_ENABLED", True, asbool):
+            cls.enabled = False
+            return
+
         if ddconfig._ci_visibility_agentless_enabled:
             if not os.getenv("_CI_DD_API_KEY", os.getenv("DD_API_KEY")):
                 log.critical(
