@@ -38,6 +38,7 @@ from ddtrace.internal.utils.http import FormData
 from ddtrace.internal.utils.http import connector
 from ddtrace.internal.utils.http import multipart
 from ddtrace.internal.utils.inspection import linenos
+from ddtrace.internal.utils.inspection import resolved_code_origin
 from ddtrace.internal.utils.inspection import undecorated
 from ddtrace.settings._agent import config as agent_config
 from ddtrace.settings.symbol_db import config as symdb_config
@@ -96,7 +97,8 @@ def get_fields(cls: type) -> t.Set[str]:
         return {
             code.co_names[b.arg]
             for a, b in zip(*(islice(t, i, None) for i, t in enumerate(tee(dis.get_instructions(code), 2))))
-            if a.opname == "LOAD_FAST" and a.arg == 0 and b.opname == "STORE_ATTR"
+            # Python 3.14 changed this to LOAD_FAST_BORROW
+            if a.opname.startswith("LOAD_FAST") and a.arg & 15 == 0 and b.opname == "STORE_ATTR"
         }
     except AttributeError:
         return set()
@@ -323,7 +325,7 @@ class Scope:
             return None
         data.seen.add(code_id)
 
-        if Path(code.co_filename).resolve() != data.origin:
+        if (code_origin := resolved_code_origin(code)) != data.origin:
             # Comes from another module.
             return None
 
@@ -337,7 +339,7 @@ class Scope:
         return Scope(
             scope_type=ScopeType.CLOSURE,  # DEV: Not in the sense of a Python closure.
             name=code.co_name,
-            source_file=str(Path(code.co_filename).resolve()),
+            source_file=str(code_origin),
             start_line=start_line,
             end_line=end_line,
             symbols=Symbol.from_code(code),
@@ -468,6 +470,7 @@ class ScopeContext:
             "ddsource": "python",
             "service": config.service or DEFAULT_SERVICE_NAME,
             "runtimeId": get_runtime_id(),
+            "type": "symdb",
         }
 
     def add_scope(self, scope: Scope) -> None:
