@@ -24,9 +24,10 @@ from ddtrace.llmobs._constants import TOTAL_TOKENS_METRIC_KEY
 from ddtrace.llmobs._integrations.base import BaseLLMIntegration
 from ddtrace.llmobs._integrations.utils import update_proxy_workflow_input_output_value
 from ddtrace.llmobs._utils import _get_attr
-from ddtrace.llmobs.utils import ToolCall
-from ddtrace.llmobs.utils import ToolDefinition
-from ddtrace.llmobs.utils import ToolResult
+from ddtrace.llmobs.types import Message
+from ddtrace.llmobs.types import ToolCall
+from ddtrace.llmobs.types import ToolDefinition
+from ddtrace.llmobs.types import ToolResult
 from ddtrace.trace import Span
 
 
@@ -69,9 +70,9 @@ class AnthropicIntegration(BaseLLMIntegration):
             span._set_ctx_item(TOOL_DEFINITIONS, tools)
         messages = kwargs.get("messages")
         system_prompt = kwargs.get("system")
-        input_messages = self._extract_input_message(messages, system_prompt)
+        input_messages = self._extract_input_message(list(messages) if messages else [], system_prompt)
 
-        output_messages = [{"content": ""}]
+        output_messages: List[Message] = [Message(content="")]
         if not span.error and response is not None:
             output_messages = self._extract_output_message(response)
         span_kind = "workflow" if span._get_ctx_item(PROXY_REQUEST) else "llm"
@@ -92,14 +93,16 @@ class AnthropicIntegration(BaseLLMIntegration):
         )
         update_proxy_workflow_input_output_value(span, span_kind)
 
-    def _extract_input_message(self, messages, system_prompt: Optional[Union[str, List[Dict[str, Any]]]] = None):
+    def _extract_input_message(
+        self, messages: List[Dict[str, Any]], system_prompt: Optional[Union[str, List[Dict[str, Any]]]] = None
+    ) -> List[Message]:
         """Extract input messages from the stored prompt.
         Anthropic allows for messages and multiple texts in a message, which requires some special casing.
         """
         if not isinstance(messages, Iterable):
             log.warning("Anthropic input must be a list of messages.")
 
-        input_messages = []
+        input_messages: List[Message] = []
         if system_prompt is not None:
             messages = [{"content": system_prompt, "role": "system"}] + messages
 
@@ -115,16 +118,16 @@ class AnthropicIntegration(BaseLLMIntegration):
                 log.warning("Anthropic input message must have content and role.")
 
             if isinstance(content, str):
-                input_messages.append({"content": content, "role": role})
+                input_messages.append(Message(content=content, role=str(role)))
 
             elif isinstance(content, list):
                 for block in content:
                     if _get_attr(block, "type", None) == "text":
-                        input_messages.append({"content": _get_attr(block, "text", ""), "role": role})
+                        input_messages.append(Message(content=str(_get_attr(block, "text", "")), role=str(role)))
 
                     elif _get_attr(block, "type", None) == "image":
                         # Store a placeholder for potentially enormous binary image data.
-                        input_messages.append({"content": "([IMAGE DETECTED])", "role": role})
+                        input_messages.append(Message(content="([IMAGE DETECTED])", role=str(role)))
 
                     elif _get_attr(block, "type", None) == "tool_use":
                         text = _get_attr(block, "text", None)
@@ -132,26 +135,26 @@ class AnthropicIntegration(BaseLLMIntegration):
                         if isinstance(input_data, str):
                             input_data = json.loads(input_data)
                         tool_call_info = ToolCall(
-                            name=_get_attr(block, "name", ""),
+                            name=str(_get_attr(block, "name", "")),
                             arguments=input_data,
-                            tool_id=_get_attr(block, "id", ""),
-                            type=_get_attr(block, "type", ""),
+                            tool_id=str(_get_attr(block, "id", "")),
+                            type=str(_get_attr(block, "type", "")),
                         )
                         if text is None:
                             text = ""
-                        input_messages.append({"content": text, "role": role, "tool_calls": [tool_call_info]})
+                        input_messages.append(Message(content=str(text), role=str(role), tool_calls=[tool_call_info]))
 
                     elif _get_attr(block, "type", None) == "tool_result":
                         content = _get_attr(block, "content", None)
                         formatted_content = self._format_tool_result_content(content)
                         tool_result_info = ToolResult(
                             result=formatted_content,
-                            tool_id=_get_attr(block, "tool_use_id", ""),
+                            tool_id=str(_get_attr(block, "tool_use_id", "")),
                             type="tool_result",
                         )
-                        input_messages.append({"content": "", "role": role, "tool_results": [tool_result_info]})
+                        input_messages.append(Message(content="", role=str(role), tool_results=[tool_result_info]))
                     else:
-                        input_messages.append({"content": str(block), "role": role})
+                        input_messages.append(Message(content=str(block), role=str(role)))
 
         return input_messages
 
@@ -169,34 +172,33 @@ class AnthropicIntegration(BaseLLMIntegration):
             return ",".join(formatted_content)
         return str(content)
 
-    def _extract_output_message(self, response):
+    def _extract_output_message(self, response) -> List[Message]:
         """Extract output messages from the stored response."""
-        output_messages = []
+        output_messages: List[Message] = []
         content = _get_attr(response, "content", "")
         role = _get_attr(response, "role", "")
 
         if isinstance(content, str):
-            return [{"content": content, "role": role}]
+            return [Message(content=content, role=str(role))]
 
         elif isinstance(content, list):
             for completion in content:
                 text = _get_attr(completion, "text", None)
                 if isinstance(text, str):
-                    output_messages.append({"content": text, "role": role})
-                else:
-                    if _get_attr(completion, "type", None) == "tool_use":
-                        input_data = _get_attr(completion, "input", "")
-                        if isinstance(input_data, str):
-                            input_data = json.loads(input_data)
-                        tool_call_info = ToolCall(
-                            name=_get_attr(completion, "name", ""),
-                            arguments=input_data,
-                            tool_id=_get_attr(completion, "id", ""),
-                            type=_get_attr(completion, "type", ""),
-                        )
-                        if text is None:
-                            text = ""
-                        output_messages.append({"content": text, "role": role, "tool_calls": [tool_call_info]})
+                    output_messages.append(Message(content=text, role=str(role)))
+                elif _get_attr(completion, "type", None) == "tool_use":
+                    input_data = _get_attr(completion, "input", "")
+                    if isinstance(input_data, str):
+                        input_data = json.loads(input_data)
+                    tool_call_info = ToolCall(
+                        name=str(_get_attr(completion, "name", "")),
+                        arguments=input_data,
+                        tool_id=str(_get_attr(completion, "id", "")),
+                        type=str(_get_attr(completion, "type", "")),
+                    )
+                    if text is None:
+                        text = ""
+                    output_messages.append(Message(content=str(text), role=str(role), tool_calls=[tool_call_info]))
         return output_messages
 
     def _extract_usage(self, span: Span, usage: Dict[str, Any]):
