@@ -35,14 +35,18 @@ from ddtrace.llmobs._constants import SPAN_KIND
 from ddtrace.llmobs._constants import SPAN_LINKS
 from ddtrace.llmobs._constants import TOTAL_TOKENS_METRIC_KEY
 from ddtrace.llmobs._integrations.base import BaseLLMIntegration
+from ddtrace.llmobs._integrations.utils import LANGCHAIN_ROLE_MAPPING
 from ddtrace.llmobs._integrations.utils import extract_instance_metadata_from_stack
 from ddtrace.llmobs._integrations.utils import format_langchain_io
 from ddtrace.llmobs._integrations.utils import update_proxy_workflow_input_output_value
 from ddtrace.llmobs._utils import _get_attr
 from ddtrace.llmobs._utils import _get_nearest_llmobs_ancestor
+from ddtrace.llmobs._utils import _validate_prompt
 from ddtrace.llmobs._utils import safe_json
-from ddtrace.llmobs._utils import validate_prompt
-from ddtrace.llmobs.utils import Document
+from ddtrace.llmobs.types import Document
+from ddtrace.llmobs.types import Message
+from ddtrace.llmobs.types import ToolCall
+from ddtrace.llmobs.types import _SpanLink
 from ddtrace.trace import Span
 
 
@@ -298,7 +302,7 @@ class LangChainIntegration(BaseLLMIntegration):
         This is done by removing span links of previous steps in the chain from the parent span (if it is a chain).
         We add output->output span links at every step.
         """
-        parent_links = parent_span._get_ctx_item(SPAN_LINKS) or []
+        parent_links: List[_SpanLink] = parent_span._get_ctx_item(SPAN_LINKS) or []
         pop_indices = self._get_popped_span_link_indices(parent_span, parent_links, invoker_spans, from_output)
 
         self._set_span_links(
@@ -310,7 +314,7 @@ class LangChainIntegration(BaseLLMIntegration):
         )
 
     def _get_popped_span_link_indices(
-        self, parent_span: Span, parent_links: List[Dict[str, Any]], invoker_spans: List[Span], from_output: bool
+        self, parent_span: Span, parent_links: List[_SpanLink], invoker_spans: List[Span], from_output: bool
     ) -> List[int]:
         """
         Returns a list of indices to pop from the parent span links list
@@ -340,17 +344,17 @@ class LangChainIntegration(BaseLLMIntegration):
         popped_span_link_indices: Optional[List[int]] = None,
     ) -> None:
         """Sets the span links on the given span along with the existing links."""
-        existing_links = span._get_ctx_item(SPAN_LINKS) or []
+        existing_links: List[_SpanLink] = span._get_ctx_item(SPAN_LINKS) or []
 
         if popped_span_link_indices:
             existing_links = [link for i, link in enumerate(existing_links) if i not in popped_span_link_indices]
 
-        links = [
-            {
-                "trace_id": format_trace_id(from_span.trace_id),
-                "span_id": str(from_span.span_id),
-                "attributes": {"from": link_from, "to": link_to},
-            }
+        links: List[_SpanLink] = [
+            _SpanLink(
+                trace_id=format_trace_id(from_span.trace_id),
+                span_id=str(from_span.span_id),
+                attributes={"from": link_from, "to": link_to},
+            )
             for from_span in from_spans
             if from_span is not None
         ]
@@ -384,7 +388,7 @@ class LangChainIntegration(BaseLLMIntegration):
                 instance=instance,
                 internal_variable_names=["instance", "self", "step"],
                 default_variable_name="unknown_prompt_template",
-                default_module_name="unknown_module",
+                default_module_name="langchain",
                 frame_start_offset=2,
                 frame_search_depth=10,
             )
@@ -440,7 +444,7 @@ class LangChainIntegration(BaseLLMIntegration):
             # chat and llm take the same input types for streamed calls
             input_messages = self._handle_stream_input_messages(prompts)
         else:
-            input_messages = [{"content": str(prompt)} for prompt in prompts]
+            input_messages = [Message(content=str(prompt)) for prompt in prompts]
 
         span._set_ctx_items(
             {
@@ -454,12 +458,12 @@ class LangChainIntegration(BaseLLMIntegration):
         self._llmobs_set_metadata(span, kwargs)
 
         if span.error:
-            span._set_ctx_item(output_tag_key, [{"content": ""}])
+            span._set_ctx_item(output_tag_key, [Message(content="")])
             return
         if stream:
-            message_content = [{"content": completions}]  # single completion for streams
+            message_content = [Message(content=completions)]  # single completion for streams
         else:
-            message_content = [{"content": completion[0].text} for completion in completions.generations]
+            message_content = [Message(content=completion[0].text) for completion in completions.generations]
             if not is_workflow:
                 input_tokens, output_tokens, total_tokens = self.check_token_usage_chat_or_llm_result(completions)
                 if total_tokens > 0:
@@ -493,7 +497,7 @@ class LangChainIntegration(BaseLLMIntegration):
         output_tag_key = OUTPUT_VALUE if is_workflow else OUTPUT_MESSAGES
         stream = span.get_tag("langchain.request.stream")
 
-        input_messages = []
+        input_messages: List[Message] = []
         if stream:
             chat_messages = get_argument_value(args, kwargs, 0, "input")
             input_messages = self._handle_stream_input_messages(chat_messages)
@@ -507,7 +511,7 @@ class LangChainIntegration(BaseLLMIntegration):
                         message.get("content", "") if isinstance(message, dict) else getattr(message, "content", "")
                     )
                     role = getattr(message, "role", ROLE_MAPPING.get(getattr(message, "type", ""), ""))
-                    input_messages.append({"content": str(content), "role": str(role)})
+                    input_messages.append(Message(content=str(content), role=str(role)))
                     tool_call_id = _get_attr(message, "tool_call_id", "")
                     if not is_workflow and tool_call_id:
                         core.dispatch(
@@ -520,14 +524,14 @@ class LangChainIntegration(BaseLLMIntegration):
         span._set_ctx_item(input_tag_key, input_messages)
 
         if span.error:
-            span._set_ctx_item(output_tag_key, [{"content": ""}])
+            span._set_ctx_item(output_tag_key, [Message(content="")])
             return
 
-        output_messages = []
+        output_messages: List[Message] = []
         if stream:
             content = chat_completions.content
             role = chat_completions.__class__.__name__.replace("MessageChunk", "").lower()  # AIMessageChunk --> ai
-            span._set_ctx_item(output_tag_key, [{"content": content, "role": ROLE_MAPPING.get(role, "")}])
+            span._set_ctx_item(output_tag_key, [Message(content=content, role=ROLE_MAPPING.get(role, ""))])
             return
 
         input_tokens, output_tokens, total_tokens = 0, 0, 0
@@ -542,7 +546,7 @@ class LangChainIntegration(BaseLLMIntegration):
             for chat_completion in message_set:
                 chat_completion_msg = chat_completion.message
                 role = getattr(chat_completion_msg, "role", ROLE_MAPPING.get(chat_completion_msg.type, ""))
-                output_message = {"content": str(chat_completion.text), "role": role}
+                output_message = Message(content=str(chat_completion.text), role=role)
                 tool_calls_info = self._extract_tool_calls(chat_completion_msg)
                 if not is_workflow:
                     for tool_call in tool_calls_info:
@@ -589,30 +593,30 @@ class LangChainIntegration(BaseLLMIntegration):
             }
             span._set_ctx_item(METRICS, metrics)
 
-    def _extract_tool_calls(self, chat_completion_msg: Any) -> List[Dict[str, Any]]:
+    def _extract_tool_calls(self, chat_completion_msg: Any) -> List[ToolCall]:
         """Extracts tool calls from a langchain chat completion."""
         tool_calls = getattr(chat_completion_msg, "tool_calls", None)
-        tool_calls_info = []
+        tool_calls_info: List[ToolCall] = []
         if tool_calls:
             if not isinstance(tool_calls, list):
                 tool_calls = [tool_calls]
             for tool_call in tool_calls:
-                tool_call_info = {
-                    "name": tool_call.get("name", ""),
-                    "arguments": tool_call.get("args", {}),  # this is already a dict
-                    "tool_id": tool_call.get("id", ""),
-                }
+                tool_call_info = ToolCall(
+                    name=tool_call.get("name", ""),
+                    arguments=tool_call.get("args", {}),  # this is already a dict
+                    tool_id=tool_call.get("id", ""),
+                )
                 tool_calls_info.append(tool_call_info)
         return tool_calls_info
 
-    def _handle_stream_input_messages(self, inputs):
-        input_messages = []
+    def _handle_stream_input_messages(self, inputs) -> List[Message]:
+        input_messages: List[Message] = []
         if hasattr(inputs, "to_messages"):  # isinstance(inputs, langchain_core.prompt_values.PromptValue)
             inputs = inputs.to_messages()
         elif not isinstance(inputs, list):
             inputs = [inputs]
         for inp in inputs:
-            inp_message = {}
+            inp_message = Message()
             content, role = None, None
             if isinstance(inp, dict):
                 content = str(inp.get("content", ""))
@@ -676,7 +680,7 @@ class LangChainIntegration(BaseLLMIntegration):
                 else:
                     if isinstance(input_texts, str):
                         input_texts = [input_texts]
-                    input_documents = [Document(text=str(doc)) for doc in input_texts]
+                    input_documents: List[Document] = [Document(text=str(doc)) for doc in input_texts]
                     span._set_ctx_item(input_tag_key, input_documents)
         except TypeError:
             log.warning("Failed to serialize embedding input data to JSON")
@@ -725,7 +729,7 @@ class LangChainIntegration(BaseLLMIntegration):
         if is_workflow:
             span._set_ctx_item(OUTPUT_VALUE, "[{} document(s) retrieved]".format(len(output_documents)))
             return
-        documents = []
+        documents: List[Document] = []
         for d in output_documents:
             doc = Document(text=d.page_content)
             doc["id"] = getattr(d, "id", "")
@@ -843,12 +847,65 @@ class LangChainIntegration(BaseLLMIntegration):
 
     def handle_prompt_template_invoke(self, instance, result, args: List[Any], kwargs: Dict[str, Any]):
         """On prompt template invoke, store the template on the result so its available to consuming .invoke()."""
-        template, variables = None, None
+        chat_template, template, variables = None, None, None
         if hasattr(instance, "template") and isinstance(instance.template, str):
             template = instance.template
-        variables = get_argument_value(args, kwargs, 0, "input", optional=True)
 
-        if not template or not variables or not isinstance(variables, dict):
+        if (
+            isinstance(getattr(instance, "messages", None), list)
+            and result is not None
+            and isinstance(getattr(result, "messages", None), list)
+        ):
+            messages = []
+            if len(instance.messages) != len(result.messages):
+                # langchain allows for message placeholder templates, but we don't support them yet
+                # these are templates where a template variable takes as its value several complete messages
+                log.debug(
+                    "Instance messages and result messages have different lengths; message placeholder not supported"
+                )
+                return
+
+            for m, r in zip(instance.messages, result.messages):
+                # message templates do not have a role: the role is derived from the instance class
+                # instead, we use the resulting message
+                role = getattr(r, "role", None)
+                if not role and hasattr(r, "type"):
+                    role = LANGCHAIN_ROLE_MAPPING.get(r.type)
+                if not role:
+                    role = "unknown"
+
+                if hasattr(m, "content"):
+                    # a message in the template that is not a template itself
+                    messages.append({"role": role, "content": m.content})
+                elif hasattr(m, "prompt") and hasattr(m.prompt, "template"):
+                    # a template message
+                    messages.append({"role": role, "content": str(m.prompt.template or "")})
+                else:
+                    messages = []
+                    log.debug("Failed to parse template messages")
+                    break
+            chat_template = messages if messages else None
+
+        tags = {}
+        if isinstance(getattr(instance, "metadata", None), dict):
+            metadata = instance.metadata
+            tags = {key: value for key, value in metadata.items() if isinstance(value, str)}
+
+        variables = get_argument_value(args, kwargs, 0, "input", optional=True)
+        if (
+            isinstance(variables, str)
+            and isinstance(getattr(instance, "input_variables", None), list)
+            and len(instance.input_variables) == 1
+        ):
+            # variables should be passed in as a dict, but a string is allowed if there is only one input variable
+            variables = {instance.input_variables[0]: variables}
+
+        if (
+            (not template and not chat_template)
+            or (template and chat_template)
+            or not variables
+            or not isinstance(variables, dict)
+        ):
             return
 
         prompt_id = self._get_prompt_variable_name(instance)
@@ -856,10 +913,12 @@ class LangChainIntegration(BaseLLMIntegration):
         prompt = {
             "variables": variables,
             "template": template,
+            "chat_template": chat_template,
             "id": prompt_id if prompt_id is not None else "unknown",
             "version": "0.0.0",
             "rag_context_variables": [],
             "rag_query_variables": [],
+            "tags": tags,
         }
 
         try:
@@ -885,7 +944,7 @@ class LangChainIntegration(BaseLLMIntegration):
         if prompt_value_meta is not None:
             prompt = prompt_value_meta
             try:
-                prompt = validate_prompt(prompt)
+                prompt = _validate_prompt(prompt, strict_validation=True)
                 span._set_ctx_item(INPUT_PROMPT, prompt)
             except Exception as e:
                 log.debug("Failed to validate langchain prompt", e)
