@@ -8,19 +8,12 @@ from typing import Dict
 from typing import List
 from typing import Optional
 from typing import Tuple
+from typing import TypedDict
 from typing import Union
 from typing import cast
 from urllib.parse import quote
 from urllib.parse import urlparse
 
-
-# TypedDict was added to typing in python 3.8
-try:
-    from typing import TypedDict
-except ImportError:
-    from typing_extensions import TypedDict
-from typing_extensions import NotRequired
-
 import ddtrace
 from ddtrace import config
 from ddtrace.internal import agent
@@ -52,28 +45,33 @@ from ddtrace.llmobs._experiment import JSONType
 from ddtrace.llmobs._experiment import Project
 from ddtrace.llmobs._experiment import UpdatableDatasetRecord
 from ddtrace.llmobs._utils import safe_json
+from ddtrace.llmobs.types import _Meta
+from ddtrace.llmobs.types import _SpanLink
 from ddtrace.settings._agent import config as agent_config
 
 
 logger = get_logger(__name__)
 
 
-class LLMObsSpanEvent(TypedDict):
+class _LLMObsSpanEventOptional(TypedDict, total=False):
+    session_id: str
+    service: str
+    status_message: str
+    collection_errors: List[str]
+    span_links: List[_SpanLink]
+
+
+class LLMObsSpanEvent(_LLMObsSpanEventOptional):
     span_id: str
     trace_id: str
     parent_id: str
-    session_id: NotRequired[str]
     tags: List[str]
-    service: NotRequired[str]
     name: str
     start_ns: int
     duration: int
     status: str
-    status_message: NotRequired[str]
-    meta: Dict[str, Any]
+    meta: _Meta
     metrics: Dict[str, Any]
-    collection_errors: NotRequired[List[str]]
-    span_links: NotRequired[List[Dict[str, str]]]
     _dd: Dict[str, str]
 
 
@@ -91,6 +89,7 @@ class LLMObsEvaluationMetricEvent(TypedDict, total=False):
 
 
 class LLMObsExperimentEvalMetricEvent(TypedDict, total=False):
+    metric_source: str
     span_id: str
     trace_id: str
     timestamp_ms: int
@@ -313,7 +312,7 @@ class LLMObsExperimentsClient(BaseLLMObsWriter):
     EVP_SUBDOMAIN_HEADER_VALUE = EXP_SUBDOMAIN_NAME
     AGENTLESS_BASE_URL = AGENTLESS_EXP_BASE_URL
     ENDPOINT = ""
-    TIMEOUT = 5.0
+    TIMEOUT = 10.0
     BULK_UPLOAD_TIMEOUT = 60.0
     LIST_RECORDS_TIMEOUT = 20
     SUPPORTED_UPLOAD_EXTS = {"csv"}
