@@ -1,4 +1,5 @@
-import typing  # noqa:F401
+from asyncio.locks import Lock
+import typing
 
 from .. import collector
 from . import _lock
@@ -13,8 +14,7 @@ class AsyncioLockCollector(_lock.LockCollector):
 
     PROFILED_LOCK_CLASS = _ProfiledAsyncioLock
 
-    def _start_service(self):
-        # type: (...) -> None
+    def _start_service(self) -> None:
         """Start collecting lock usage."""
         try:
             import asyncio
@@ -23,12 +23,11 @@ class AsyncioLockCollector(_lock.LockCollector):
         self._asyncio_module = asyncio
         return super(AsyncioLockCollector, self)._start_service()
 
-    def _get_patch_target(self):
-        # type: (...) -> typing.Any
+    def _get_patch_target(self) -> typing.Type[Lock]:
         return self._asyncio_module.Lock
 
     def _set_patch_target(
-        self, value  # type: typing.Any
-    ):
-        # type: (...) -> None
+        self,
+        value: typing.Any,
+    ) -> None:
         self._asyncio_module.Lock = value  # type: ignore[misc]
