@@ -1,10 +1,10 @@
-"""This Flask application is imported on tests.appsec.appsec_utils.gunicorn_server"""
+"""This Flask application is imported on tests.appsec.appsec_utils.gunicorn_flask_server"""
 import ddtrace.auto  # noqa: F401  # isort: skip
 import copy
 import os
 import re
 import shlex
-import subprocess  # nosec
+import subprocess
 
 from flask import Flask
 from flask import Response
@@ -13,9 +13,9 @@ from flask import request
 import urllib3
 from wrapt import FunctionWrapper
 
-import ddtrace
 from ddtrace import tracer
 from ddtrace.appsec._iast import ddtrace_iast_flask_patch
+from ddtrace.appsec._iast._iast_request_context_base import is_iast_request_enabled
 from ddtrace.appsec._iast._taint_tracking._taint_objects_base import is_pyobject_tainted
 from ddtrace.internal.utils.formats import asbool
 from tests.appsec.iast_packages.packages.pkg_aiohttp import pkg_aiohttp
@@ -97,9 +97,6 @@ from tests.appsec.iast_packages.packages.pkg_zipp import pkg_zipp
 import tests.appsec.integrations.flask_tests.module_with_import_errors as module_with_import_errors
 
 
-# Patch urllib3 since they are not patched automatically
-ddtrace.patch_all(urllib3=True)  # type: ignore
-
 app = Flask(__name__)
 app.register_blueprint(pkg_aiohttp)
 app.register_blueprint(pkg_aiosignal)
@@ -206,6 +203,22 @@ def appsec_body_hang():
     return "OK_test-body-hang", 200
 
 
+@app.route("/iast-enabled", methods=["GET"])
+def iast_enabled():
+    """Return whether IAST request context is enabled, after an optional delay.
+
+    This endpoint mirrors the FastAPI version used in concurrency tests.
+    """
+    try:
+        delay_ms = int(request.args.get("delay_ms", "200"))
+    except Exception:
+        delay_ms = 200
+    import time as _time
+
+    _time.sleep(max(0, delay_ms) / 1000.0)
+    return Response("true" if is_iast_request_enabled() else "false")
+
+
 @app.route("/iast-cmdi-vulnerability", methods=["GET"])
 def view_iast_iast_cmdi_vulnerability():
     filename = request.args.get("filename")
@@ -963,10 +976,17 @@ def iast_ast_patching_non_re_search():
     return resp
 
 
-@app.route("/common-modules-patch-read", methods=["GET"])
-def test_flask_common_modules_patch_read():
-    copy_open = copy.deepcopy(open)
-    return Response(f"OK: {isinstance(copy_open, FunctionWrapper)}")
+@app.route("/common-modules-patch", methods=["GET"])
+def test_flask_common_modules_patch():
+    function = request.args.get("function")
+    copy_function = ""
+    if function == "open":
+        copy_function = copy.deepcopy(open)
+    elif function == "os_system":
+        copy_function = os.system
+    elif function == "subprocess_popen":
+        copy_function = subprocess.Popen.__init__
+    return Response(f"OK: {isinstance(copy_function, FunctionWrapper)}")
 
 
 @app.route("/returnheaders", methods=["GET"])
@@ -980,14 +1000,78 @@ def return_headers(*args, **kwargs):
 @app.route("/vulnerablerequestdownstream", methods=["GET"])
 def vulnerable_request_downstream():
     _weak_hash_vulnerability()
+    port = str(request.args.get("port", "8050"))
     # Propagate the received headers to the downstream service
     http_poolmanager = urllib3.PoolManager(num_pools=1)
     # Sending a GET request and getting back response as HTTPResponse object.
-    response = http_poolmanager.request("GET", "http://localhost:8050/returnheaders")
+    response = http_poolmanager.request("GET", f"http://localhost:{port}/returnheaders")
     http_poolmanager.clear()
     return Response(response.data)
 
 
+@app.route("/gevent-greenlet", methods=["GET"])
+def gevent_greenlet():
+    """Spawn and join a gevent Greenlet to ensure no deadlocks with IAST/gevent.
+
+    This endpoint is used by tests parametrized with Gunicorn/gevent configurations
+    to validate stability under gevent monkey-patching.
+    """
+    try:
+        import gevent
+        from gevent import Greenlet
+
+        def _noop():
+            return True
+
+        g = Greenlet(_noop)
+        g.start()
+        gevent.joinall([g])
+        ok = g.value is True
+    except Exception:
+        # If gevent is not available, still return OK to keep the test minimal
+        ok = True
+    return Response(f"OK:{ok}")
+
+
+@app.route("/socketpair", methods=["GET"])
+def socketpair_roundtrip():
+    """Exercise socket.socketpair send/recv lifecycle and return OK status."""
+    try:
+        import socket
+
+        s1, s2 = socket.socketpair()
+        try:
+            msg = b"ping"
+            s1.sendall(msg)
+            data = s2.recv(16)
+            ok = data == msg
+        finally:
+            s1.close()
+            s2.close()
+    except Exception:
+        ok = False
+    return Response(f"OK:{ok}")
+
+
+@app.route("/subprocess-popen", methods=["GET"])
+def subprocess_popen_ok():
+    """Run a trivial subprocess to ensure process lifecycle behaves under gevent."""
+    ok = True
+    try:
+        pass
+        subp = (
+            subprocess.Popen(args=["/bin/echo", "ok"])
+            if os.path.exists("/bin/echo")
+            else subprocess.Popen(args=["echo", "ok"])
+        )
+        subp.communicate()
+        rc = subp.wait()
+        ok = rc == 0
+    except Exception:
+        ok = False
+    return Response(f"OK:{ok}")
+
+
 if __name__ == "__main__":
     env_port = os.getenv("FLASK_RUN_PORT", 8000)
     debug = asbool(os.getenv("FLASK_DEBUG", "false"))
