@@ -4,6 +4,7 @@ from pathlib import Path
 import signal
 import subprocess
 import sys
+import typing as _t
 
 from requests.exceptions import ConnectionError  # noqa: A004
 
@@ -19,7 +20,7 @@ FILE_PATH = Path(__file__).resolve().parent
 
 
 @contextmanager
-def gunicorn_server(
+def gunicorn_flask_server(
     use_ddtrace_cmd=True,
     appsec_enabled="true",
     iast_enabled="false",
@@ -90,6 +91,60 @@ def flask_server(
     )
 
 
+@contextmanager
+def gunicorn_django_server(
+    use_ddtrace_cmd: bool = True,
+    appsec_enabled: str = "true",
+    iast_enabled: str = "false",
+    remote_configuration_enabled: str = "true",
+    tracer_enabled: str = "true",
+    apm_tracing_enabled: str = "true",
+    token: str = None,
+    port: int = 8000,
+    workers: str = "1",
+    use_threads: bool = False,
+    use_gevent: bool = False,
+    assert_debug: bool = False,
+    env: dict = None,
+):
+    """Run the Django test application under Gunicorn.
+
+    Uses the WSGI application at
+    ``tests.appsec.integrations.django_tests.django_app.wsgi:application``.
+    Mirrors options supported by gunicorn_flask_server.
+    """
+    cmd = ["gunicorn", "-w", workers, "--log-level", "debug"]
+    if use_ddtrace_cmd:
+        cmd = ["python", "-m", "ddtrace.commands.ddtrace_run"] + cmd
+    if use_threads:
+        cmd += ["--threads", "1"]
+    if use_gevent:
+        cmd += ["-k", "gevent"]
+    cmd += [
+        "-b",
+        f"0.0.0.0:{port}",
+        "tests.appsec.integrations.django_tests.django_app.wsgi:application",
+    ]
+    # Ensure Django settings are set for WSGI
+    extra_env = {
+        "DJANGO_SETTINGS_MODULE": "tests.appsec.integrations.django_tests.django_app.settings",
+    }
+    if env:
+        extra_env.update(env)
+    yield from appsec_application_server(
+        cmd,
+        appsec_enabled=appsec_enabled,
+        iast_enabled=iast_enabled,
+        apm_tracing_enabled=apm_tracing_enabled,
+        remote_configuration_enabled=remote_configuration_enabled,
+        tracer_enabled=tracer_enabled,
+        token=token,
+        env=extra_env,
+        port=port,
+        assert_debug=assert_debug,
+    )
+
+
 @contextmanager
 def django_server(
     python_cmd="python",
@@ -103,6 +158,8 @@ def django_server(
     env=None,
     assert_debug=False,
     manual_propagation_debug=False,
+    *args,
+    **kwargs,
 ):
     """
     Context manager that runs a Django test server in a subprocess.
@@ -197,6 +254,16 @@ def appsec_application_server(
     assert_debug=False,
     manual_propagation_debug=False,
 ):
+    """Start an application server subprocess for AppSec/IAST tests.
+
+    This helper optionally applies CPU/memory limits to the spawned subprocess when the following
+    environment variables are set (Linux/Unix only):
+      - TEST_SUBPROC_MEM_MB: integer megabytes to cap address space (RLIMIT_AS)
+      - TEST_SUBPROC_CPU_AFFINITY: comma-separated CPU indices for sched_setaffinity (Linux)
+      - TEST_SUBPROC_NICE: integer niceness value to apply via os.nice()
+
+    This is opt-in and introduces no behavior change unless the variables are provided.
+    """
     env = _build_env(env, file_path=FILE_PATH)
     env["DD_REMOTE_CONFIG_POLL_INTERVAL_SECONDS"] = "0.5"
     env["DD_REMOTE_CONFIGURATION_ENABLED"] = remote_configuration_enabled
@@ -234,6 +301,12 @@ def appsec_application_server(
             subprocess_kwargs["stderr"] = subprocess.PIPE
         subprocess_kwargs["text"] = True
 
+    # Only set preexec_fn on POSIX. It's ignored/unsupported on Windows.
+    if os.name == "posix":
+        preexec = _make_preexec()
+        if preexec is not None:
+            subprocess_kwargs["preexec_fn"] = preexec  # type: ignore[assignment]
+
     server_process = subprocess.Popen(cmd, **subprocess_kwargs)
     try:
         client = Client("http://0.0.0.0:%s" % port)
@@ -281,3 +354,48 @@ def appsec_application_server(
             assert "Return from " in process_output
             assert "Return value is tainted" in process_output
             assert "Tainted arguments:" in process_output
+
+
+def _make_preexec() -> _t.Optional[_t.Callable[[], None]]:
+    """Create a preexec_fn that applies resource limits if configured.
+
+    Returns None if no limits were requested.
+    """
+    mem_mb = os.environ.get("TEST_SUBPROC_MEM_MB")
+    cpu_aff = os.environ.get("TEST_SUBPROC_CPU_AFFINITY")
+    nice_val = os.environ.get("TEST_SUBPROC_NICE")
+    if not any((mem_mb, cpu_aff, nice_val)):
+        return None
+
+    # Import inside to keep portability on Windows.
+    try:
+        import resource  # type: ignore[attr-defined]
+    except Exception:  # pragma: no cover
+        resource = None  # type: ignore[assignment]
+
+    def _preexec():  # pragma: no cover - exercised in integration tests
+        # Set process group leader (already done via start_new_session)
+        # Apply niceness first to reduce priority
+        if nice_val is not None:
+            try:
+                os.nice(int(nice_val))
+            except Exception:
+                pass
+        # CPU affinity (Linux only)
+        if cpu_aff:
+            try:
+                cpus = {int(x) for x in cpu_aff.split(",") if x.strip() != ""}
+                if hasattr(os, "sched_setaffinity") and cpus:
+                    os.sched_setaffinity(0, cpus)  # type: ignore[attr-defined]
+            except Exception:
+                pass
+        # Memory limit via RLIMIT_AS (virtual memory)
+        if mem_mb and resource is not None:
+            try:
+                limit_bytes = int(mem_mb) * 1024 * 1024
+                resource.setrlimit(resource.RLIMIT_AS, (limit_bytes, limit_bytes))
+            except Exception:
+                # Fall back silently if not supported
+                pass
+
+    return _preexec
