@@ -7,14 +7,15 @@ import pytest
 from ddtrace._trace.pin import Pin
 from ddtrace.appsec._iast import enable_iast_propagation
 from ddtrace.appsec._iast import load_iast
+from ddtrace.appsec._iast import oce
+from ddtrace.appsec._iast._taint_tracking._context import debug_context_array_free_slots_number
 from ddtrace.appsec._iast.main import patch_iast
 from ddtrace.contrib.internal.django.patch import patch as django_patch
 from ddtrace.contrib.internal.requests.patch import patch as requests_patch
 from ddtrace.internal import core
-from tests.appsec.iast.iast_utils import _end_iast_context_and_oce
-from tests.appsec.iast.iast_utils import _start_iast_context_and_oce
 from tests.utils import DummyTracer
 from tests.utils import TracerSpanContainer
+from tests.utils import override_config
 from tests.utils import override_env
 from tests.utils import override_global_config
 
@@ -60,7 +61,8 @@ def tracer():
 
     # Yield to our test
     core.tracer = tracer
-    yield tracer
+    with override_config("django", dict(_tracer=tracer)):
+        yield tracer
     tracer.pop()
     core.tracer = original_tracer
     # Reset the tracer pinned to Django and unpatch
@@ -86,10 +88,25 @@ def iast_span(tracer):
             _iast_request_sampling=100.0,
         )
     ):
+        oce.reconfigure()
+        container = TracerSpanContainer(tracer)
+        assert debug_context_array_free_slots_number() > 0
+        yield container
+        container.reset()
+
+
+@pytest.fixture
+def iast_span_disabled(tracer):
+    with override_global_config(
+        dict(
+            _iast_enabled=False,
+            _iast_deduplication_enabled=False,
+            _iast_request_sampling=100.0,
+        )
+    ):
+        oce.reconfigure()
         container = TracerSpanContainer(tracer)
-        _start_iast_context_and_oce()
         yield container
-        _end_iast_context_and_oce()
         container.reset()
 
 
@@ -103,10 +120,9 @@ def test_spans_2_vuln_per_request_deduplication(tracer):
             _iast_request_sampling=100.0,
         )
     ):
+        oce.reconfigure()
         container = TracerSpanContainer(tracer)
-        _start_iast_context_and_oce()
         yield container
-        _end_iast_context_and_oce()
         container.reset()
 
 
@@ -134,8 +150,7 @@ def iast_spans_with_zero_sampling(tracer):
             _iast_request_sampling=0.0,
         )
     ):
+        oce.reconfigure()
         container = TracerSpanContainer(tracer)
-        _start_iast_context_and_oce()
         yield container
-        _end_iast_context_and_oce()
         container.reset()
