@@ -52,6 +52,7 @@ class BotoTest(TracerTestCase):
         self.assertEqual(span.get_tag(http.METHOD), "POST")
         self.assertEqual(span.get_tag("aws.region"), "us-west-2")
         self.assertEqual(span.get_tag("region"), "us-west-2")
+        self.assertEqual(span.get_tag("aws.partition"), "aws")
         self.assertEqual(span.get_tag("component"), "boto")
         self.assertEqual(span.get_tag("span.kind"), "client")
 
@@ -67,6 +68,7 @@ class BotoTest(TracerTestCase):
         self.assertEqual(span.get_tag(http.METHOD), "POST")
         self.assertEqual(span.get_tag("aws.region"), "us-west-2")
         self.assertEqual(span.get_tag("region"), "us-west-2")
+        self.assertEqual(span.get_tag("aws.partition"), "aws")
         self.assertEqual(span.get_tag("component"), "boto")
         self.assertEqual(span.get_tag("span.kind"), "client")
         self.assertEqual(span.service, "test-boto-tracing.ec2")
@@ -495,6 +497,7 @@ class BotoTest(TracerTestCase):
         self.assertEqual(span.get_tag(http.METHOD), "GET")
         self.assertEqual(span.get_tag("aws.region"), "us-east-2")
         self.assertEqual(span.get_tag("region"), "us-east-2")
+        self.assertEqual(span.get_tag("aws.partition"), "aws")
         self.assertEqual(span.get_tag("aws.operation"), "list_functions")
         self.assertEqual(span.get_tag("component"), "boto")
         self.assertEqual(span.get_tag("span.kind"), "client")
@@ -612,6 +615,7 @@ class BotoTest(TracerTestCase):
         assert_is_measured(span)
         self.assertEqual(span.get_tag("aws.region"), "us-west-2")
         self.assertEqual(span.get_tag("region"), "us-west-2")
+        self.assertEqual(span.get_tag("aws.partition"), "aws")
         self.assertEqual(span.get_tag("aws.operation"), "GetFederationToken")
         self.assertEqual(span.get_tag("component"), "boto")
         self.assertEqual(span.get_tag("span.kind"), "client")
@@ -750,6 +754,7 @@ class BotoTest(TracerTestCase):
         span = spans[0]
         self.assertEqual(span.get_tag("aws.region"), "us-west-2")
         self.assertEqual(span.get_tag("region"), "us-west-2")
+        self.assertEqual(span.get_tag("aws.partition"), "aws")
         self.assertEqual(span.get_tag("component"), "boto")
         self.assertEqual(span.get_tag("span.kind"), "client")
         self.assertEqual(span.service, "test-boto-tracing.elasticache")
@@ -783,6 +788,7 @@ class BotoTest(TracerTestCase):
         self.assertEqual(dd_span.get_tag(http.METHOD), "POST")
         self.assertEqual(dd_span.get_tag("aws.region"), "us-west-2")
         self.assertEqual(dd_span.get_tag("region"), "us-west-2")
+        self.assertEqual(dd_span.get_tag("aws.partition"), "aws")
 
         with ot_tracer.start_active_span("ot_span"):
             ec2.run_instances(21)
@@ -800,6 +806,7 @@ class BotoTest(TracerTestCase):
         self.assertEqual(dd_span.get_tag(http.METHOD), "POST")
         self.assertEqual(dd_span.get_tag("aws.region"), "us-west-2")
         self.assertEqual(dd_span.get_tag("region"), "us-west-2")
+        self.assertEqual(dd_span.get_tag("aws.partition"), "aws")
         self.assertEqual(dd_span.get_tag("component"), "boto")
         self.assertEqual(dd_span.get_tag("span.kind"), "client")
         self.assertEqual(dd_span.service, "test-boto-tracing.ec2")
