@@ -1,13 +1,13 @@
 import mock
 import pytest
 
+from ddtrace._trace.pin import Pin
 from ddtrace.contrib.dbapi_async import FetchTracedAsyncCursor
 from ddtrace.contrib.dbapi_async import TracedAsyncConnection
 from ddtrace.contrib.dbapi_async import TracedAsyncCursor
 from ddtrace.propagation._database_monitoring import _DBM_Propagator
 from ddtrace.settings._config import Config
 from ddtrace.settings.integration import IntegrationConfig
-from ddtrace.trace import Pin
 from ddtrace.trace import Span  # noqa:F401
 from tests.contrib.asyncio.utils import AsyncioTestCase
 from tests.contrib.asyncio.utils import mark_asyncio
