@@ -1,7 +1,7 @@
 import flask
 
+from ddtrace._trace.pin import Pin
 from ddtrace.contrib.internal.flask.patch import unpatch
-from ddtrace.trace import Pin
 
 from . import BaseFlaskTestCase
 
