@@ -3,9 +3,9 @@ from io import StringIO
 
 import flask
 
+from ddtrace._trace.pin import Pin
 from ddtrace.contrib.internal.flask.patch import flask_version
 from ddtrace.contrib.internal.flask.patch import unpatch
-from ddtrace.trace import Pin
 
 from . import BaseFlaskTestCase
 
