@@ -6,15 +6,17 @@ from unittest.mock import patch as mock_patch
 
 import pytest
 
+from ddtrace._trace.pin import Pin
 from ddtrace.contrib.internal.google_genai.patch import patch
 from ddtrace.contrib.internal.google_genai.patch import unpatch
 from ddtrace.llmobs import LLMObs
-from ddtrace.trace import Pin
 from tests.contrib.google_genai.utils import MOCK_EMBED_CONTENT_RESPONSE
 from tests.contrib.google_genai.utils import MOCK_GENERATE_CONTENT_RESPONSE
 from tests.contrib.google_genai.utils import MOCK_GENERATE_CONTENT_RESPONSE_STREAM
 from tests.contrib.google_genai.utils import MOCK_TOOL_CALL_RESPONSE
+from tests.contrib.google_genai.utils import MOCK_TOOL_CALL_RESPONSE_STREAM
 from tests.contrib.google_genai.utils import MOCK_TOOL_FINAL_RESPONSE
+from tests.contrib.google_genai.utils import MOCK_TOOL_FINAL_RESPONSE_STREAM
 from tests.llmobs._utils import TestLLMObsSpanWriter
 from tests.utils import DummyTracer
 from tests.utils import DummyWriter
@@ -155,6 +157,65 @@ def mock_generate_content_with_tools(genai):
         yield
 
 
+@pytest.fixture
+def mock_generate_content_stream_with_tools(genai):
+    call_count = 0
+
+    def _fake_generate_content_stream_with_tools(self, *, model: str, contents, config=None):
+        nonlocal call_count
+        call_count += 1
+
+        if call_count == 1:
+            for chunk in MOCK_TOOL_CALL_RESPONSE_STREAM:
+                yield chunk
+        else:
+            for chunk in MOCK_TOOL_FINAL_RESPONSE_STREAM:
+                yield chunk
+
+    with mock_patch.object(genai.models.Models, "_generate_content_stream", _fake_generate_content_stream_with_tools):
+        yield
+
+
+@pytest.fixture
+def mock_async_generate_content_with_tools(genai):
+    call_count = 0
+
+    async def _fake_async_generate_content_with_tools(self, *, model: str, contents, config=None):
+        nonlocal call_count
+        call_count += 1
+
+        if call_count == 1:
+            return MOCK_TOOL_CALL_RESPONSE
+        return MOCK_TOOL_FINAL_RESPONSE
+
+    with mock_patch.object(genai.models.AsyncModels, "_generate_content", _fake_async_generate_content_with_tools):
+        yield
+
+
+@pytest.fixture
+def mock_async_generate_content_stream_with_tools(genai):
+    call_count = 0
+
+    async def _fake_async_generate_content_stream_with_tools(self, *, model: str, contents, config=None):
+        nonlocal call_count
+        call_count += 1
+
+        async def _async_iterator():
+            if call_count == 1:
+                for chunk in MOCK_TOOL_CALL_RESPONSE_STREAM:
+                    yield chunk
+            else:
+                for chunk in MOCK_TOOL_FINAL_RESPONSE_STREAM:
+                    yield chunk
+
+        return _async_iterator()
+
+    with mock_patch.object(
+        genai.models.AsyncModels, "_generate_content_stream", _fake_async_generate_content_stream_with_tools
+    ):
+        yield
+
+
 @pytest.fixture
 def mock_embed_content(genai):
     """
