@@ -8,6 +8,7 @@ from requests.exceptions import InvalidURL
 from requests.exceptions import MissingSchema
 
 from ddtrace import config
+from ddtrace._trace.pin import Pin
 from ddtrace.constants import ERROR_MSG
 from ddtrace.constants import ERROR_STACK
 from ddtrace.constants import ERROR_TYPE
@@ -17,7 +18,6 @@ from ddtrace.contrib.internal.requests.patch import patch
 from ddtrace.contrib.internal.requests.patch import unpatch
 from ddtrace.ext import http
 from ddtrace.internal.schema import DEFAULT_SPAN_SERVICE_NAME
-from ddtrace.trace import Pin
 from tests.opentracer.utils import init_tracer
 from tests.utils import TracerTestCase
 from tests.utils import assert_is_measured
@@ -282,7 +282,11 @@ class TestRequests(BaseRequestTestCase, TracerTestCase):
 
     def test_user_set_service_name(self):
         # ensure a service name set by the user has precedence
-        cfg = Pin._get_config(self.session)
+        cfg = {}
+        pin = Pin.get_from(self.session)
+        if pin:
+            cfg = pin._config
+
         cfg["service_name"] = "clients"
         out = self.session.get(URL_200)
         assert out.status_code == 200
@@ -293,7 +297,11 @@ class TestRequests(BaseRequestTestCase, TracerTestCase):
 
     def test_user_set_service(self):
         # ensure a service name set by the user has precedence
-        cfg = Pin._get_config(self.session)
+        cfg = {}
+        pin = Pin.get_from(self.session)
+        if pin:
+            cfg = pin._config
+
         cfg["service"] = "clients"
         out = self.session.get(URL_200)
         assert out.status_code == 200
@@ -334,7 +342,11 @@ class TestRequests(BaseRequestTestCase, TracerTestCase):
     def test_user_service_name_precedence(self):
         # ensure the user service name takes precedence over
         # the parent Span
-        cfg = Pin._get_config(self.session)
+        cfg = {}
+        pin = Pin.get_from(self.session)
+        if pin:
+            cfg = pin._config
+
         cfg["service_name"] = "clients"
         with self.tracer.trace("parent.span", service="web"):
             out = self.session.get(URL_200)
@@ -350,7 +362,11 @@ class TestRequests(BaseRequestTestCase, TracerTestCase):
     def test_split_by_domain_with_ampersat(self):
         # Regression test for: https://github.com/DataDog/dd-trace-py/issues/4062
         # ensure a service name is generated by the domain name
-        cfg = Pin._get_config(self.session)
+        cfg = {}
+        pin = Pin.get_from(self.session)
+        if pin:
+            cfg = pin._config
+
         cfg["split_by_domain"] = True
         # domain name should take precedence over monkey_service
         cfg["service_name"] = "monkey_service"
@@ -369,7 +385,11 @@ class TestRequests(BaseRequestTestCase, TracerTestCase):
     def test_split_by_domain(self):
         # ensure a service name is generated by the domain name
         # of the ongoing call
-        cfg = Pin._get_config(self.session)
+        cfg = {}
+        pin = Pin.get_from(self.session)
+        if pin:
+            cfg = pin._config
+
         cfg["split_by_domain"] = True
         out = self.session.get(URL_200)
         assert out.status_code == 200
@@ -384,7 +404,11 @@ class TestRequests(BaseRequestTestCase, TracerTestCase):
 
     def test_split_by_domain_precedence(self):
         # ensure the split by domain has precedence all the time
-        cfg = Pin._get_config(self.session)
+        cfg = {}
+        pin = Pin.get_from(self.session)
+        if pin:
+            cfg = pin._config
+
         cfg["split_by_domain"] = True
         cfg["service_name"] = "intake"
         out = self.session.get(URL_200)
@@ -401,7 +425,11 @@ class TestRequests(BaseRequestTestCase, TracerTestCase):
     def test_split_by_domain_wrong(self):
         # ensure the split by domain doesn't crash in case of a wrong URL;
         # in that case, no spans are created
-        cfg = Pin._get_config(self.session)
+        cfg = {}
+        pin = Pin.get_from(self.session)
+        if pin:
+            cfg = pin._config
+
         cfg["split_by_domain"] = True
         with pytest.raises((MissingSchema, InvalidURL)):
             self.session.get("http:/some>thing")
@@ -412,7 +440,11 @@ class TestRequests(BaseRequestTestCase, TracerTestCase):
 
     def test_split_by_domain_remove_auth_in_url(self):
         # ensure that auth details are stripped from URL
-        cfg = Pin._get_config(self.session)
+        cfg = {}
+        pin = Pin.get_from(self.session)
+        if pin:
+            cfg = pin._config
+
         cfg["split_by_domain"] = True
         out = self.session.get(f"http://user:pass@{HOST_AND_PORT}")
         assert out.status_code == 200
@@ -426,7 +458,11 @@ class TestRequests(BaseRequestTestCase, TracerTestCase):
 
     def test_split_by_domain_includes_port(self):
         # ensure that port is included if present in URL
-        cfg = Pin._get_config(self.session)
+        cfg = {}
+        pin = Pin.get_from(self.session)
+        if pin:
+            cfg = pin._config
+
         cfg["split_by_domain"] = True
         out = self.session.get(f"http://{HOST_AND_PORT}")
         assert out.status_code == 200
@@ -440,7 +476,11 @@ class TestRequests(BaseRequestTestCase, TracerTestCase):
 
     def test_split_by_domain_includes_port_path(self):
         # ensure that port is included if present in URL but not path
-        cfg = Pin._get_config(self.session)
+        cfg = {}
+        pin = Pin.get_from(self.session)
+        if pin:
+            cfg = pin._config
+
         cfg["split_by_domain"] = True
         out = self.session.get(f"http://{HOST_AND_PORT}/anything/v1/foo")
         assert out.status_code == 200
@@ -459,7 +499,11 @@ class TestRequests(BaseRequestTestCase, TracerTestCase):
         spans = self.pop_spans()
         assert spans[0].service == "override"
 
-        cfg = Pin._get_config(self.session)
+        cfg = {}
+        pin = Pin.get_from(self.session)
+        if pin:
+            cfg = pin._config
+
         cfg["service"] = "override2"
         out = self.session.get(URL_200)
         assert out.status_code == 200
