@@ -5,7 +5,7 @@ import pytest
 
 from ddtrace.debugging._encoding import BufferFull
 from ddtrace.debugging._encoding import SignalQueue
-from ddtrace.debugging._uploader import LogsIntakeUploaderV1
+from ddtrace.debugging._uploader import SignalUploader
 
 
 # DEV: Using float('inf') with lock wait intervals may cause an OverflowError
@@ -13,12 +13,13 @@ from ddtrace.debugging._uploader import LogsIntakeUploaderV1
 LONG_INTERVAL = 2147483647.0
 
 
-class MockLogsIntakeUploaderV1(LogsIntakeUploaderV1):
+class MockSignalUploader(SignalUploader):
     def __init__(self, *args, **kwargs):
-        super(MockLogsIntakeUploaderV1, self).__init__(*args, **kwargs)
+        super(MockSignalUploader, self).__init__(*args, **kwargs)
         self.queue = Queue()
+        self._state = self._online
 
-    def _write(self, payload):
+    def _write(self, payload, endpoint):
         self.queue.put(payload.decode())
 
     @property
@@ -26,12 +27,13 @@ class MockLogsIntakeUploaderV1(LogsIntakeUploaderV1):
         return [json.loads(data) for data in self.queue]
 
 
-class ActiveBatchJsonEncoder(MockLogsIntakeUploaderV1):
+class ActiveBatchJsonEncoder(MockSignalUploader):
     def __init__(self, size=1 << 10, interval=1):
         super(ActiveBatchJsonEncoder, self).__init__(interval)
 
         # Override the signal queue
-        self._queue = SignalQueue(None, size, self.on_full)
+        for track in self._tracks.values():
+            track.queue = SignalQueue(None, size, self.on_full)
 
     def on_full(self, item, encoded):
         self.periodic()
@@ -39,9 +41,10 @@ class ActiveBatchJsonEncoder(MockLogsIntakeUploaderV1):
 
 def test_uploader_batching():
     with ActiveBatchJsonEncoder(interval=LONG_INTERVAL) as uploader:
+        queue = uploader._tracks.values().__iter__().__next__().queue
         for _ in range(5):
-            uploader._queue.put_encoded(None, "hello".encode("utf-8"))
-            uploader._queue.put_encoded(None, "world".encode("utf-8"))
+            queue.put_encoded(None, "hello".encode("utf-8"))
+            queue.put_encoded(None, "world".encode("utf-8"))
             uploader.periodic()
 
         for _ in range(5):
@@ -56,8 +59,9 @@ def test_uploader_full_buffer():
         assert n
 
         with pytest.raises(BufferFull):
+            queue = uploader._tracks.values().__iter__().__next__().queue
             for _ in range(2 * n):
-                uploader._queue.put_encoded(None, item.encode("utf-8"))
+                queue.put_encoded(None, item.encode("utf-8"))
 
         # The full buffer forces a flush
         uploader.queue.get(timeout=0.5)
