@@ -15,6 +15,7 @@ from unittest import mock
 from pyfakefs.fake_filesystem_unittest import TestCase
 import pytest
 
+from ddtrace.internal.compat import PYTHON_VERSION_INFO
 from ddtrace.internal.flare._subscribers import TracerFlareSubscriber
 from ddtrace.internal.flare.flare import TRACER_FLARE_FILE_HANDLER_NAME
 from ddtrace.internal.flare.flare import Flare
@@ -628,6 +629,9 @@ class TracerFlareTests(TestCase):
         self.flare.revert_configs()
 
 
+@pytest.mark.skipif(
+    PYTHON_VERSION_INFO >= (3, 14), reason="pyfakefs seems not to fully work with multiprocessing under Python 3.14"
+)
 class TracerFlareMultiprocessTests(TestCase):
     def setUp(self):
         self.setUpPyfakefs()
