@@ -12,6 +12,7 @@ from ddtrace.llmobs import _constants as const
 from ddtrace.llmobs._constants import PARENT_ID_KEY
 from ddtrace.llmobs._constants import ROOT_PARENT_ID
 from ddtrace.llmobs._utils import _get_session_id
+from ddtrace.llmobs.types import Prompt
 from tests.llmobs._utils import _expected_llmobs_llm_span_event
 
 
@@ -364,9 +365,9 @@ def test_error_is_set(tracer, llmobs_events):
             llm_span._set_ctx_item(const.SPAN_KIND, "llm")
             raise ValueError("error")
     span_event = llmobs_events[0]
-    assert span_event["meta"]["error.message"] == "error"
-    assert "ValueError" in span_event["meta"]["error.type"]
-    assert 'raise ValueError("error")' in span_event["meta"]["error.stack"]
+    assert span_event["meta"]["error"]["message"] == "error"
+    assert "ValueError" in span_event["meta"]["error"]["type"]
+    assert 'raise ValueError("error")' in span_event["meta"]["error"]["stack"]
 
 
 def test_model_provider_defaults_to_custom(tracer, llmobs_events):
@@ -460,15 +461,42 @@ def test_structured_io_data(llmobs, llmobs_backend):
 
 def test_structured_prompt_data(llmobs, llmobs_backend):
     with llmobs.llm() as span:
-        llmobs.annotate(span, prompt={"template": "test {{value}}"})
+        llmobs.annotate(span, input_data={"data": "test1"}, prompt={"template": "test {{value}}"})
+    events = llmobs_backend.wait_for_num_events(num=1)
+    assert len(events) == 1
+    assert events[0][0]["spans"][0]["meta"]["input"]["prompt"] == {
+        "id": "unnamed-ml-app_unnamed-prompt",
+        "template": "test {{value}}",
+        "_dd_context_variable_keys": ["context"],
+        "_dd_query_variable_keys": ["question"],
+    }
+
+
+def test_structured_prompt_data_v2(llmobs, llmobs_backend):
+    prompt = Prompt(
+        id="test",
+        chat_template=[{"role": "user", "content": "test {{value}}"}],
+        variables={"value": "test", "context": "test", "question": "test"},
+        tags={"env": "prod", "llm": "openai"},
+        rag_context_variables=["context"],
+        rag_query_variables=["question"],
+    )
+    with llmobs.llm() as span:
+        llmobs.annotate(
+            span,
+            prompt=prompt,
+        )
     events = llmobs_backend.wait_for_num_events(num=1)
     assert len(events) == 1
     assert events[0][0]["spans"][0]["meta"]["input"] == {
         "prompt": {
-            "template": "test {{value}}",
+            "id": "test",
+            "chat_template": [{"role": "user", "content": "test {{value}}"}],
+            "variables": {"value": "test", "context": "test", "question": "test"},
+            "tags": {"env": "prod", "llm": "openai"},
             "_dd_context_variable_keys": ["context"],
             "_dd_query_variable_keys": ["question"],
-        },
+        }
     }
 
 
@@ -628,3 +656,27 @@ def test_trace_id_propagation_with_non_llm_parent(llmobs, llmobs_events):
     # LLMObs trace IDs should be different from APM trace ID
     assert first_child_event["trace_id"] != first_child_event["_dd"]["apm_trace_id"]
     assert second_child_event["trace_id"] != second_child_event["_dd"]["apm_trace_id"]
+
+
+@pytest.mark.parametrize("llmobs_env", [{"DD_APM_TRACING_ENABLED": "false"}])
+def test_apm_traces_dropped_when_disabled(llmobs, llmobs_events, tracer, llmobs_env):
+    from tests.utils import DummyWriter
+
+    dummy_writer = DummyWriter()
+    tracer._span_aggregator.writer = dummy_writer
+
+    with tracer.trace("apm_span") as apm_span:
+        apm_span.set_tag("operation", "test")
+
+    # Create an LLMObs span (should be sent to LLMObs but not APM)
+    with llmobs.llm(model_name="test-model") as llm_span:
+        llmobs.annotate(llm_span, input_data="test input", output_data="test output")
+
+    # Check that no APM traces were sent to the writer
+    assert len(dummy_writer.traces) == 0, "APM traces should be dropped when DD_APM_TRACING_ENABLED=false"
+
+    # But LLMObs events should still be sent
+    assert len(llmobs_events) == 1
+    llm_event = llmobs_events[0]
+    assert llm_event["meta"]["span"]["kind"] == "llm"
+    assert llm_event["meta"]["model_name"] == "test-model"
