@@ -4,18 +4,17 @@ import time
 import mock
 import pytest
 
-from ddtrace.llmobs._constants import AGENTLESS_EVAL_BASE_URL
 from ddtrace.llmobs._writer import LLMObsEvalMetricWriter
+from ddtrace.llmobs._writer import LLMObsEvaluationMetricEvent
 from tests.utils import override_global_config
 
 
 DD_SITE = "datad0g.com"
-AGENTLESS_URL = "{}.{}".format(AGENTLESS_EVAL_BASE_URL, DD_SITE)
 INTAKE_ENDPOINT = "https://api.datad0g.com/api/intake/llm-obs/v2/eval-metric"
 DD_API_KEY = os.getenv("DD_API_KEY", default="<not-a-real-api-key>")
 
 
-def _categorical_metric_event():
+def _categorical_metric_event(label: str, value: str) -> LLMObsEvaluationMetricEvent:
     return {
         "join_on": {
             "span": {
@@ -24,14 +23,14 @@ def _categorical_metric_event():
             },
         },
         "metric_type": "categorical",
-        "categorical_value": "very",
-        "label": "toxicity",
+        "categorical_value": value,
+        "label": label,
         "ml_app": "dummy-ml-app",
-        "timestamp_ms": round(time.time() * 1000),
+        "timestamp_ms": 1756910127022,
     }
 
 
-def _score_metric_event():
+def _score_metric_event(label: str, value: float) -> LLMObsEvaluationMetricEvent:
     return {
         "join_on": {
             "span": {
@@ -40,10 +39,10 @@ def _score_metric_event():
             },
         },
         "metric_type": "score",
-        "label": "sentiment",
-        "score_value": 0.9,
+        "label": label,
+        "score_value": value,
         "ml_app": "dummy-ml-app",
-        "timestamp_ms": round(time.time() * 1000),
+        "timestamp_ms": 1756910127022,
     }
 
 
@@ -64,16 +63,23 @@ def test_buffer_limit(mock_writer_logs):
 
 
 @pytest.mark.skip(reason="Skipping due to flakiness in hitting the staging endpoint")
-def test_send_metric_bad_api_key(mock_writer_logs):
-    llmobs_eval_metric_writer = LLMObsEvalMetricWriter(1, 1, is_agentless=True, _site=DD_SITE, _api_key="<bad-api-key>")
+def test_send_metric_bad_api_key(mock_writer_logs, llmobs_api_proxy_url):
+    llmobs_eval_metric_writer = LLMObsEvalMetricWriter(
+        interval=1,
+        timeout=1,
+        is_agentless=True,
+        _override_url=llmobs_api_proxy_url,
+        _api_key="<bad-api-key>",
+    )
+
+    llmobs_eval_metric_writer.enqueue(_categorical_metric_event(label="api-key", value="wrong-api-key"))
 
-    llmobs_eval_metric_writer.enqueue(_categorical_metric_event())
     llmobs_eval_metric_writer.periodic()
     mock_writer_logs.error.assert_called_with(
         "failed to send %d LLMObs %s events to %s, got response code %d, status: %s",
         1,
         "evaluation_metric",
-        INTAKE_ENDPOINT,
+        f"{llmobs_api_proxy_url}/api/intake/llm-obs/v2/eval-metric",
         403,
         b'{"status":"error","code":403,"errors":["Forbidden"],"statuspage":"http://status.datadoghq.com","twitter":"http://twitter.com/datadogops","email":"support@datadoghq.com"}',  # noqa
     )
@@ -82,7 +88,7 @@ def test_send_metric_bad_api_key(mock_writer_logs):
 def test_send_metric_no_api_key(mock_writer_logs):
     with override_global_config(dict(_dd_api_key="")):
         llmobs_eval_metric_writer = LLMObsEvalMetricWriter(1, 1, is_agentless=True, _site=DD_SITE, _api_key="")
-        llmobs_eval_metric_writer.enqueue(_categorical_metric_event())
+        llmobs_eval_metric_writer.enqueue(_categorical_metric_event(label="toxicity", value="very"))
         llmobs_eval_metric_writer.periodic()
     mock_writer_logs.warning.assert_called_with(
         "A Datadog API key is required for sending data to LLM Observability in agentless mode. "
@@ -91,39 +97,55 @@ def test_send_metric_no_api_key(mock_writer_logs):
     )
 
 
-@pytest.mark.vcr_logs
-def test_send_categorical_metric(mock_writer_logs):
-    llmobs_eval_metric_writer = LLMObsEvalMetricWriter(1, 1, is_agentless=True, _site=DD_SITE, _api_key=DD_API_KEY)
-    llmobs_eval_metric_writer.enqueue(_categorical_metric_event())
+def test_send_categorical_metric(mock_writer_logs, llmobs_api_proxy_url):
+    llmobs_eval_metric_writer = LLMObsEvalMetricWriter(
+        interval=1,
+        timeout=1,
+        is_agentless=True,
+        _api_key=DD_API_KEY,
+        _override_url=llmobs_api_proxy_url,
+    )
+    llmobs_eval_metric_writer.enqueue(_categorical_metric_event(label="toxicity", value="very"))
     llmobs_eval_metric_writer.periodic()
     mock_writer_logs.debug.assert_has_calls(
         [mock.call("encoded %d LLMObs %s events to be sent", 1, "evaluation_metric")]
     )
 
 
-@pytest.mark.vcr_logs
-def test_send_score_metric(mock_writer_logs):
-    llmobs_eval_metric_writer = LLMObsEvalMetricWriter(1, 1, is_agentless=True, _site=DD_SITE, _api_key=DD_API_KEY)
-    llmobs_eval_metric_writer.enqueue(_score_metric_event())
+def test_send_score_metric(mock_writer_logs, llmobs_api_proxy_url):
+    llmobs_eval_metric_writer = LLMObsEvalMetricWriter(
+        interval=1,
+        timeout=1,
+        is_agentless=True,
+        _site=DD_SITE,
+        _api_key=DD_API_KEY,
+        _override_url=llmobs_api_proxy_url,
+    )
+    llmobs_eval_metric_writer.enqueue(_score_metric_event(label="sentiment", value=0.9))
     llmobs_eval_metric_writer.periodic()
     mock_writer_logs.debug.assert_has_calls(
         [mock.call("encoded %d LLMObs %s events to be sent", 1, "evaluation_metric")]
     )
 
 
-@pytest.mark.vcr_logs
-def test_send_timed_events(mock_writer_logs):
-    llmobs_eval_metric_writer = LLMObsEvalMetricWriter(0.01, 1, is_agentless=True, _site=DD_SITE, _api_key=DD_API_KEY)
+def test_send_timed_events(mock_writer_logs, llmobs_api_proxy_url):
+    llmobs_eval_metric_writer = LLMObsEvalMetricWriter(
+        interval=0.01,
+        timeout=1,
+        is_agentless=True,
+        _api_key=DD_API_KEY,
+        _override_url=llmobs_api_proxy_url,
+    )
     llmobs_eval_metric_writer.start()
     mock_writer_logs.reset_mock()
 
-    llmobs_eval_metric_writer.enqueue(_score_metric_event())
+    llmobs_eval_metric_writer.enqueue(_score_metric_event(label="sentiment", value=0.9))
     time.sleep(0.1)
     mock_writer_logs.debug.assert_has_calls(
         [mock.call("encoded %d LLMObs %s events to be sent", 1, "evaluation_metric")]
     )
     mock_writer_logs.reset_mock()
-    llmobs_eval_metric_writer.enqueue(_categorical_metric_event())
+    llmobs_eval_metric_writer.enqueue(_categorical_metric_event(label="toxicity", value="very"))
     time.sleep(0.1)
     mock_writer_logs.debug.assert_has_calls(
         [mock.call("encoded %d LLMObs %s events to be sent", 1, "evaluation_metric")]
@@ -135,8 +157,8 @@ def test_send_timed_events(mock_writer_logs):
 def test_send_multiple_events(mock_writer_logs):
     llmobs_eval_metric_writer = LLMObsEvalMetricWriter(1, 1, is_agentless=True, _site=DD_SITE, _api_key=DD_API_KEY)
     mock_writer_logs.reset_mock()
-    llmobs_eval_metric_writer.enqueue(_score_metric_event())
-    llmobs_eval_metric_writer.enqueue(_categorical_metric_event())
+    llmobs_eval_metric_writer.enqueue(_score_metric_event(label="sentiment", value=0.9))
+    llmobs_eval_metric_writer.enqueue(_categorical_metric_event(label="toxicity", value="very"))
     llmobs_eval_metric_writer.periodic()
     mock_writer_logs.debug.assert_has_calls(
         [mock.call("encoded %d LLMObs %s events to be sent", 2, "evaluation_metric")]
@@ -153,13 +175,13 @@ def test_send_on_exit(mock_writer_logs, run_python_code_in_subprocess):
     out, err, status, pid = run_python_code_in_subprocess(
         """
 from ddtrace.llmobs._writer import LLMObsEvalMetricWriter
-from tests.llmobs.test_llmobs_eval_metric_agentless_writer import _score_metric_event
+from tests.llmobs.test_llmobs_eval_metric_agentless_writer import _categorical_metric_event
 
 llmobs_eval_metric_writer = LLMObsEvalMetricWriter(
-    0.01, 1, is_agentless=True, _site="datad0g.com", _api_key="<not-a-real-key>"
+    interval=0.01, timeout=1, is_agentless=True, _api_key="<not-a-real-key>", _override_url="http://localhost:9126/vcr/datadog/"
 )
 llmobs_eval_metric_writer.start()
-llmobs_eval_metric_writer.enqueue(_score_metric_event())
+llmobs_eval_metric_writer.enqueue(_categorical_metric_event(label="api-key", value="wrong-api-key"))
 """,
         env=env,
     )
